@@ -38,6 +38,8 @@
 #include <math.h>
 #include <kfileitem.h>
 #include <klocale.h>
+#include <klineedit.h>
+#include <kdebug.h>
 
 /////////////////////////////////////////////////////////////////////////////
 /////////////////////// Pie related widgets /////////////////////////////////
@@ -62,8 +64,8 @@ QColor KRPie::colors[12]={Qt::red,Qt::blue,Qt::green,Qt::cyan,Qt::magenta,Qt::gr
 /////////////// KRFSDisplay - Filesystem / Freespace Display /////////////////
 //////////////////////////////////////////////////////////////////////////////
 // This is the full constructor: use it for a mounted filesystem
-KRFSDisplay::KRFSDisplay(QWidget *parent, QString _alias, QString _realName, 
-    long _total, long _free) : QWidget(parent), totalSpace(_total), 
+KRFSDisplay::KRFSDisplay(QWidget *parent, QString _alias, QString _realName,
+    KIO::filesize_t _total, KIO::filesize_t _free) : QWidget(parent), totalSpace(_total),
     freeSpace(_free), alias(_alias), realName(_realName), mounted(true),
     empty(false), supermount(false) {
   resize(150,200);
@@ -137,11 +139,11 @@ void KRFSDisplay::paintEvent(QPaintEvent *) {
       // the "used space" slice
       float i=((float)(totalSpace-freeSpace)/(totalSpace)) * 360.0;
       paint.setBrush(Qt::gray);
-      paint.drawPie(LEFT,BOTTOM-Z_HEIGHT,WIDTH,HEIGHT,STARTANGLE,DEG(i));
+      paint.drawPie(LEFT,BOTTOM-Z_HEIGHT,WIDTH,HEIGHT,STARTANGLE,(int)DEG(i));
       // if we need to draw a 3d stripe ...
       if (i>180.0) {
         for (int j=1; j<Z_HEIGHT; ++j) 
-          paint.drawArc(LEFT,BOTTOM-j,WIDTH,HEIGHT,STARTANGLE-16*180,DEG(i-180.0));
+          paint.drawArc(LEFT,BOTTOM-j,WIDTH,HEIGHT,STARTANGLE-16*180,(int)(DEG(i-180.0)));
       }
     } else {  // if the filesystem is unmounted...
       paint.setFont(QFont("helvetica",12,QFont::Bold));  
@@ -150,10 +152,10 @@ void KRFSDisplay::paintEvent(QPaintEvent *) {
   } else {  // if the widget is in empty situation...
   
   }
-}    
+}
 
 ////////////////////////////////////////////////////////////////////////////////
-KRPie::KRPie(long _totalSize, QWidget *parent) : QWidget(parent,0), totalSize(_totalSize) {
+KRPie::KRPie(KIO::filesize_t _totalSize, QWidget *parent) : QWidget(parent,0), totalSize(_totalSize) {
   slices.setAutoDelete(true); // kill items when they are removed
   slices.append(new KRPieSlice(100,Qt::yellow,"DEFAULT"));
   sizeLeft=totalSize;
@@ -171,7 +173,7 @@ void KRPie::paintEvent(QPaintEvent *) {
     // angles are negative to create a clock-wise drawing of slices
     float angle=-(slice->getPerct()/100*360)*16;
     for (int i=1; i<Z_HEIGHT; ++i) 
-      paint.drawPie(LEFT,BOTTOM+i,WIDTH,HEIGHT,sAngle,angle);
+      paint.drawPie(LEFT,BOTTOM+i,WIDTH,HEIGHT,(int)sAngle,(int)angle);
     sAngle+=angle;
   }  
   paint.setPen(Qt::yellow);   // pen
@@ -184,11 +186,11 @@ void KRPie::paintEvent(QPaintEvent *) {
     paint.setPen(slice->getColor());
     // angles are negative to create a clock-wise drawing of slices
     float angle=-(slice->getPerct()/100*360)*16;
-    paint.drawPie(LEFT,BOTTOM,WIDTH,HEIGHT,sAngle,angle);
+    paint.drawPie(LEFT,BOTTOM,WIDTH,HEIGHT,(int)sAngle,(int)angle);
     sAngle+=angle;
   }  
 
-    
+
   paint.setPen(Qt::black);
   // the pie
 //  paint.drawPie(LEFT,BOTTOM,WIDTH,HEIGHT,STARTANGLE,360*16);
@@ -200,7 +202,7 @@ void KRPie::paintEvent(QPaintEvent *) {
 
 }
 
-void KRPie::addSlice(long size,QString label) {
+void KRPie::addSlice(KIO::filesize_t size,QString label) {
   int i=(slices.count() % 12);
   slices.removeLast();
   slices.append(new KRPieSlice(size*100/totalSize,colors[i],label));
@@ -208,4 +210,24 @@ void KRPie::addSlice(long size,QString label) {
   slices.append(new KRPieSlice(sizeLeft*100/totalSize,Qt::yellow,"DEFAULT"));  
 }
 
+////////////////////////////////////////////////////
+/////////////////// KrQuickSearch  /////////////////
+////////////////////////////////////////////////////
+KrQuickSearch::KrQuickSearch(QWidget *parent, const char * name): KLineEdit(parent,name) {}
+
+void KrQuickSearch::myKeyPressEvent(QKeyEvent *e) {
+   switch (e->key()) {
+      case Key_Up:
+      case Key_Down:
+      case Key_Escape:
+      case Key_Enter:
+         emit stop(e);
+         break;
+      default:
+         kdWarning()<<"got " << e->text() << endl;
+         keyPressEvent(e);
+   }
+}
+
+
 #include "krspecialwidgets.moc"
