@@ -31,7 +31,7 @@
 #include "krspwidgets.h"
 #include "../krusader.h"
 #include "../krusaderview.h"
-#include "../Panel/kvfspanel.h"
+#include "../Panel/listpanel.h"
 #include "../kicons.h"
 #include <qcombobox.h>
 #include <qlabel.h>
@@ -56,24 +56,24 @@ QString KRSpWidgets::getMask(QString caption) {
   KRMaskChoiceSub *p=new KRMaskChoiceSub();
   p->setCaption(caption);
   p->exec();
-  if (p->selection->currentText()=="") return QString::null; 
+  if (p->selection->currentText()=="") return QString::null;
     else return p->selection->currentText();
 }
 
 void KRSpWidgets::selectCompareColorMask(int *left, int *right) {
-  int l = krApp->mainView->left->colorMask;
-  int r = krApp->mainView->right->colorMask;
+//  int l = krApp->mainView->left->colorMask;
+//  int r = krApp->mainView->right->colorMask;
 
   // create the dialog, and fill in the data according to current color mask
   colorMaskDialog *dlg = new colorMaskDialog();
-  dlg->newerLeft->setChecked(l & KRListItem::newer);
+/*  dlg->newerLeft->setChecked(l & KRListItem::newer);
   dlg->olderLeft->setChecked(l & KRListItem::older);
   dlg->identicalLeft->setChecked(l & KRListItem::identical);
   dlg->exclusiveLeft->setChecked(l & KRListItem::exclusive);
   dlg->newerRight->setChecked(r & KRListItem::newer);
   dlg->olderRight->setChecked(r & KRListItem::older);
   dlg->identicalRight->setChecked(r & KRListItem::identical);
-  dlg->exclusiveRight->setChecked(r & KRListItem::exclusive);
+  dlg->exclusiveRight->setChecked(r & KRListItem::exclusive);*/
 
   if (!dlg->exec()) {
     *left = *right = -1;
@@ -82,7 +82,7 @@ void KRSpWidgets::selectCompareColorMask(int *left, int *right) {
 
   // create masks
   (*left) = 0; (*right) = 0;
-  (*left) |= (dlg->newerLeft->isChecked() ? KRListItem::newer : 0);
+/*  (*left) |= (dlg->newerLeft->isChecked() ? KRListItem::newer : 0);
   (*left) |= (dlg->olderLeft->isChecked() ? KRListItem::older : 0);
   (*left) |= (dlg->identicalLeft->isChecked() ? KRListItem::identical : 0);
   (*left) |= (dlg->exclusiveLeft->isChecked() ? KRListItem::exclusive : 0);
@@ -90,7 +90,7 @@ void KRSpWidgets::selectCompareColorMask(int *left, int *right) {
   (*right) |= (dlg->newerRight->isChecked() ? KRListItem::newer : 0);
   (*right) |= (dlg->olderRight->isChecked() ? KRListItem::older : 0);
   (*right) |= (dlg->identicalRight->isChecked() ? KRListItem::identical : 0);
-  (*right) |= (dlg->exclusiveRight->isChecked() ? KRListItem::exclusive : 0);
+  (*right) |= (dlg->exclusiveRight->isChecked() ? KRListItem::exclusive : 0);*/
 }
 
 /////////////////////////// newFTP ////////////////////////////////////////
@@ -170,8 +170,17 @@ void KRMaskChoiceSub::reject() {
 }
 
 void KRMaskChoiceSub::accept() {
-  QString topItem=KRSpWidgets::maskList.getFirst();
-  if (topItem!=selection->currentText())
+  bool add = true;
+  char *tmp;
+  // make sure we don't have that already
+  for ( tmp = KRSpWidgets::maskList.first(); tmp ; tmp = KRSpWidgets::maskList.next() )
+    if (QString(tmp).simplifyWhiteSpace() == selection->currentText().simplifyWhiteSpace()) {
+      // break if we found one such as this
+      add = false;
+      break;
+    }
+
+  if (add)
     KRSpWidgets::maskList.insert(0,selection->currentText().local8Bit());
   // write down the predefined selections list
   QStrList list;
@@ -192,9 +201,9 @@ void KRMaskChoiceSub::addSelection() {
   QListBoxItem *i=preSelections->firstItem();
   // check if the selection already exists
   while (i!=0)
-    if (i->text()==temp) { 
-      itemExists=true; 
-      break; 
+    if (i->text()==temp) {
+      itemExists=true;
+      break;
     } else i=i->next();
   if (temp!="" && !itemExists) {
     preSelections->insertItem(selection->currentText());
