@@ -47,6 +47,9 @@
 
 kgLookFeelImpl::kgLookFeelImpl(bool f, QWidget *parent, const char *name ) :
   kgLookFeel(parent,name), firstTime(f) {
+  // fixes
+  kgMinimizeToTray->setText( i18n( "Show a tray icon                    " ) );
+
   slotSetup();
 }
 
@@ -129,6 +132,7 @@ void kgLookFeelImpl::slotApplyChanges() {
   else i=0;
   krConfig->writeEntry("Mouse Selection",i);
   editToolbar->save();  // save toolbar settings
+	editKeys->save();     // save keyboard shortcuts
   krConfig->sync();
 
   // return the toolbar to its previous state (thankx to Tin)
