@@ -39,7 +39,7 @@
 #include <qwidget.h>
 #include <klocale.h>
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kmessagebox.h>
 #include "../defaults.h"
 
