@@ -27,7 +27,7 @@
  ***************************************************************************/
 
 
-
+#include <sys/param.h>
 #include "kmountman.h"
 // QT incldues
 #include <qcstring.h>
@@ -54,13 +54,11 @@
 #define FSTAB "/etc/fstab"
 #endif
 
-#define MTAB "/etc/mtab"
-
 using namespace MountMan;
 
 KMountMan::KMountMan() : QObject(), Ready(false), Operational(false),
-                         outputBuffer(0), tempFile(0) {
-	filesystems.setAutoDelete(true);	
+                         outputBuffer(0), tempFile(0), mountManGui(0), mtab("") {
+	filesystems.setAutoDelete(true);
 	localDf=new fsData();				 // will be used to move around information
   forceUpdate();
 }
@@ -82,7 +80,11 @@ QString KMountMan::nextWord(QString &s,char c) {
   return temp;
 }
 
-void KMountMan::mainWindow() { new KMountManGUI(); }
+void KMountMan::mainWindow() {
+  mountManGui = new KMountManGUI();
+  delete mountManGui;   /* as KMountManGUI is modal, we can now delete it */
+  mountManGui = 0; /* for sanity */
+}
 
 // this version find the next word, delimeted by anything from
 // comma, space, tab or newline, in this order
@@ -102,6 +104,7 @@ QString KMountMan::nextWord(QString &s) {
   }
   QString temp=s.left(j); // find the leftmost word.
   s.remove(0,j);
+
   return temp;
 }
 
@@ -176,7 +179,11 @@ bool KMountMan::createFilesystems() {
   --i; fstab.close();  // finished with it
   for (j=0; j<=i; ++j) {
   	if (temp[0][j]=="" || temp[0][j]=="tmpfs" || temp[0][j]=="none" || temp[0][j]=="proc" ||
-        temp[0][j]=="swap" || temp[1][j]=="proc" || temp[1][j]=="/dev/pts" ||	
+#ifdef BSD
+        temp[0][j]=="swap" || temp[1][j]=="procfs" || temp[1][j]=="/dev/pts" || // FreeBSD: procfs instead of proc
+#else
+        temp[0][j]=="swap" || temp[1][j]=="proc" || temp[1][j]=="/dev/pts" ||
+#endif
         temp[1][j]=="swap" || temp[4][j]=="supermount") continue;
   	++noOfFilesystems;
   }
@@ -192,6 +199,9 @@ bool KMountMan::createFilesystems() {
 	    system->setName(temp[0][j]);
   	  system->setType(temp[1][j]);
    	  system->setMntPoint(temp[2][j]);
+      // remove trailing spaces (since mtab removes them)
+      if (system->mntPoint()[system->mntPoint().length()-1] == '/' && system->mntPoint() != "/") // also skip root!
+        system->setMntPoint(system->mntPoint().left(system->mntPoint().length()-1));
   	  system->supermount=(temp[4][j]=="supermount" ? true : false);
   	  system->options=temp[3][j];
   	  filesystems.append(system);
@@ -202,19 +212,70 @@ bool KMountMan::createFilesystems() {
   	  if (!system->supermount) mountPoints+=system->mntPoint();
     }
   }
-	kdDebug() << "Mt.Man: found the followning:\n" << forDebugOnly << "Trying DF..." << endl;
-	return true;
+	kdDebug() << "Mt.Man: found the following:\n" << forDebugOnly << "Trying DF..." << endl;
+
+#ifdef BSD
+  // FreeBSD problem: df does not retrive fs type.
+  // Workaround: execute mount -p and merge result.
+
+  KShellProcess proc;
+  proc << "mount -p";
+
+  // connect all outputs to collectOutput, to be displayed later
+  connect(&proc,SIGNAL(receivedStdout(KProcess*, char*, int)),
+          this,SLOT(collectOutput(KProcess*, char*,int)));
+  // launch
+  clearOutput();
+  if (!proc.start(KProcess::Block,KProcess::Stdout)) {
+	kdDebug() << "Unable to execute 'mount -p' !!!" << endl;
+      return true;
+  }
+
+  QString str = getOutput();
+	QTextStream t2(str, IO_ReadOnly);
+  while (!t2.atEnd()) {
+    s = t2.readLine();
+    s = s.simplifyWhiteSpace(); // remove TABs
+    if (s==QString::null || s=="") continue;  // skip empty lines in fstab
+    // temp[0]==name, temp[1]==type, temp[2]==mount point, temp[3]==options
+    // temp[4] is reserved for special cases, right now, only for supermount
+    QString temp0=nextWord(s,' ');
+    QString temp2=nextWord(s,' ');
+    QString temp1=nextWord(s,' ');
+    QString temp3=nextWord(s,' ');
+		if (temp0=="" || temp2=="/proc" || temp2=="/dev/pts" ||
+  			temp2=="swap" || temp0=="none" || temp0=="procfs" ||
+        temp0=="swap" || location(temp0)) continue;
+    else {
+	    fsData* system=new fsData();
+	    system->setName(temp0);
+  	  system->setType(temp1);
+   	  system->setMntPoint(temp2);
+  	  system->supermount=false;
+  	  system->options=temp3;
+  	  filesystems.append(system);
+      ++noOfFilesystems;
+			kdWarning() << "Mt.Man: filesystem [" << temp0 << "] found by mount -p is unlisted in /etc/fstab." << endl;
+    }
+  }
+#endif
+  return true;
 }
 
 // run DF process and when it finishes, catch output with "parseDfData"
 ///////////////////////////////////////////////////////////////////////
 void KMountMan::updateFilesystems() {
+  getMtab();  // here we get the current state of mtab for watching it later
   // create the "df -P -T" process
   tempFile = new KTempFile();
   tempFile->setAutoDelete(true);
   dfProc.clearArguments();
   dfProc.setExecutable("df");
+#ifdef BSD
+  dfProc << ">" << tempFile->name(); // FreeBSD: df instead of df -T -P
+#else
   dfProc << "-T" << "-P" << ">" << tempFile->name();
+#endif
   connect(&dfProc, SIGNAL(processExited(KProcess *)), this,
           SLOT(finishUpdateFilesystems()));
   dfProc.start(KProcess::NotifyOnExit);
@@ -243,61 +304,84 @@ void KMountMan::finishUpdateFilesystems() {
 
 fsData* KMountMan::location(QString name) {
   fsData* it;
-  for (it=filesystems.first() ; (it!=0) ; it=filesystems.next())
-   if (followLink(it->name())==followLink(name)) break;
+  for (it=filesystems.first() ; (it!=0) ; it=filesystems.next()) {
+    if (followLink(it->name())==followLink(name)) break;
+#ifdef BSD
+    if (name.left(2) == "//" && !strcasecmp(followLink(it->name()).latin1(), followLink(name).latin1())) break; // FreeBSD: ignore case due to smbfs mounts
+#endif
+  }
   return it;
 }
 
-QString KMountMan::devFromMtab(QString mntPoint) {
-  QFile mtab(MTAB);
-	if (!mtab.open(IO_ReadOnly)) {
-    kdWarning() << "Mt.Man: Unable to read /etc/mtab !!! Shutting down. (sorry)" << endl;
-    // since mtab can't be read safely, mountman stops operating.
-    Operational=Ready=false;
-    return QString::null;
+/* we cannot use collectOutput as other processes may connected to it */
+void KMountMan::collectMtab(KProcess *p, char *buffer,int buflen) {
+  // add new buffer to mtab
+  for (int i=0; i<buflen; ++i)
+    mtab += buffer[i];
+}
+
+QString KMountMan::getMtab()
+{
+  KShellProcess proc;
+  proc << "mount";
+
+  // connect all outputs by collectMtab ( collectOutput can not be used because of the watcher )
+  connect(&proc,SIGNAL(receivedStdout(KProcess*, char*, int)),
+          this,SLOT(collectMtab(KProcess*, char*,int)));
+  // launch
+  mtab = "";
+  if (!proc.start(KProcess::Block,KProcess::Stdout)) {
+    kdDebug() << "Unable to execute 'mount' !!!" << endl;
+    return "";
   }
 
+  return mtab;
+}
+
+bool KMountMan::checkMtabChanged()
+{
+  QString LastMtab = mtab;
+  return getMtab() != LastMtab;
+}
+
+QString KMountMan::devFromMtab(QString mntPoint) {
+  QString mtab = getMtab();
+
   // and read it into the temporary array
-	QTextStream t(&mtab);
-  while (!mtab.atEnd()) {
+	QTextStream t(&mtab, IO_ReadOnly );
+  while (!t.atEnd()) {
     QString dev,point;
     QString s = t.readLine().simplifyWhiteSpace();
-    dev = nextWord(s,' '); point = nextWord(s,' ');
+    dev = nextWord(s,' ');   /* device */
+    nextWord(s,' ');         /* on */
+    point = nextWord(s,' '); /* mountpoint */
     if (point==mntPoint) {
-      mtab.close();
       return dev;
     }
   }
-  mtab.close();
   return QString::null;
 }
 
 QString KMountMan::pointFromMtab(QString device) {
-  QFile mtab(MTAB);
-	if (!mtab.open(IO_ReadOnly)) {
-    kdWarning() << "Mt.Man: Unable to read /etc/mtab !!! Shutting down. (sorry)" << endl;
-    // since mtab can't be read safely, mountman stops operating.
-    Operational=Ready=false;
-    return QString::null;
-  }
+  QString mtab = getMtab();
 
   // and read it into the temporary array
-	QTextStream t(&mtab);
-  while (!mtab.atEnd()) {
+	QTextStream t(&mtab, IO_ReadOnly);
+  while (!t.atEnd()) {
     QString dev,mntPoint;
     QString s = t.readLine().simplifyWhiteSpace();
-    dev = nextWord(s,' '); mntPoint = nextWord(s,' ');
+    dev = nextWord(s,' ');   /* device */
+    nextWord(s,' ');         /* on */
+    mntPoint = nextWord(s,' '); /* mountpoint */
     if (dev==device) {
-      mtab.close();
       return mntPoint;
     }
   }
-  mtab.close();
   return QString::null;
 }
 
 KMountMan::mntStatus KMountMan::getStatus(QString mntPoint) {
-  // parse /etc/mtab and search for mntPoint
+  // parse the mount table and search for mntPoint
   bool mounted=(devFromMtab(mntPoint) != QString::null);
   if (mounted) return KMountMan::MOUNTED;
   if (mountPoints.findIndex(mntPoint)==-1)  // no such mountPoint is /etc/fstab
@@ -336,17 +420,24 @@ void KMountMan::parseDfData(QString filename) {
     temp=nextWord(s,' ');
     // avoid adding unwanted filesystems to the list
     if (temp=="tmpfs") continue;
+#ifdef BSD
+    if (temp == "procfs") continue;// FreeBSD: ignore procfs too
+#endif
     temp=followLink(temp);  // make sure DF gives us the true device and not a link
     fsData* loc=location(temp); // where is the filesystem located in our list?
     if (loc==0) {
       kdWarning() << "Mt.Man: filesystem [" << temp << "] found by DF is unlisted in /etc/fstab." << endl;
       loc=new fsData();
+      loc->supermount = false;
       filesystems.append(loc);
-			if (temp.contains("//")>0) // if it contains '//', it's a smb share
+			if (temp.contains("//")>0 ||    // if it contains '//', it's a smb share
+          temp.contains(":")>0  ||    // if it contains ':' , it's an nfs share
+          temp.startsWith("/") )      // if it is a fullpath device name
 			  loc->setName(temp);      // <patch> thanks to Cristi Dumitrescu
 			else loc->setName("/dev/"+temp);
 			newFS=true;
     }
+#ifndef BSD
     temp=nextWord(s,' ');   // catch the TYPE
     // is it supermounted ?
     if (temp=="supermount") loc->supermount=true;
@@ -356,11 +447,12 @@ void KMountMan::parseDfData(QString filename) {
     				 "] has a different type from what's stated in /etc/fstab." << endl;
       loc->setType(temp);  // DF knows best
     }
+#endif
     temp=nextWord(s,' ');
     loc->setTotalBlks(temp.toLong());
     temp=nextWord(s,' ');
-    loc->setUsedBlks(temp.toLong());
     temp=nextWord(s,' ');   // get rid of the next 2 words
+    loc->setFreeBlks(temp.toLong());
     temp=nextWord(s,' ');
     temp=nextWord(s,'\n');  // read the "mounted on" thing
     if (loc->mntPoint()!=temp) {
@@ -394,10 +486,18 @@ void KMountMan::forceUpdate() {
 
 void KMountMan::collectOutput(KProcess *p, char *buffer,int buflen) {
   if (!p) return; // don't collect data from unknown/undefined processes
-  if (!outputBuffer) outputBuffer=new QString();  // create buffer if needed
-  // add new buffer to the main output buffer
+  if (outputBuffer==0) outputBuffer = new QString();  // create buffer if needed
 
-  for (int i=0; i<buflen; ++i) (*outputBuffer)+=buffer[i];
+  // add new buffer to the main output buffer
+  for (int i=0; i<buflen; ++i)
+    (*outputBuffer) += buffer[i];
+}
+
+void KMountMan::clearOutput() {
+  if (outputBuffer != 0) {
+    delete outputBuffer;
+    outputBuffer=0;
+  }
 }
 
 // this is the generic version of mount - it receives a mntPoint and try to
@@ -442,7 +542,7 @@ void KMountMan::mount(fsData *p) {
 
   // don't allow mounting 'supermount' filesystems
   if (p->supermount) {
-    KMessageBox::information(0,i18n("Warning: you're trying to mount a 'supermount' filesystem. Supermount filesystems are (un)mounted automatically by linux upon insert/eject. This is usually a Linux-Mandrake feature.Krusader will not allow this, as it creates unpredictable behaviour."),i18n("Error"),"SupermountWarning");
+    KMessageBox::information(mountManGui,i18n("Warning: you're trying to mount a 'supermount' filesystem. Supermount filesystems are (un)mounted automatically by linux upon insert/eject. This is usually a Linux-Mandrake feature.Krusader will not allow this, as it creates unpredictable behaviour."),i18n("Error"),"SupermountWarning");
     return;
   }
   // connect all outputs to collectOutput, to be displayed later
@@ -481,7 +581,7 @@ void KMountMan::unmount(fsData *p) {
 
   // don't allow unmounting 'supermount' filesystems
   if (p->supermount) {
-    KMessageBox::information(0,i18n("Warning: you're trying to unmount a 'supermount' filesystem. Supermount filesystems are (un)mounted automatically by linux upon insert/eject. This is usually a Linux-Mandrake feature. Krusader will not allow this, as it creates unpredictable behaviour."),i18n("Error"),"SupermountWarning");
+    KMessageBox::information(mountManGui,i18n("Warning: you're trying to unmount a 'supermount' filesystem. Supermount filesystems are (un)mounted automatically by linux upon insert/eject. This is usually a Linux-Mandrake feature. Krusader will not allow this, as it creates unpredictable behaviour."),i18n("Error"),"SupermountWarning");
     return;
   }
   // connect outputs to collectOutput, to be displayed later
@@ -523,22 +623,31 @@ void KMountMan::eject(QString mntPoint) {
     KMessageBox::information(0,i18n("Error ejecting device ! You need to have 'eject' in your path."),i18n("Error"),"CantExecuteEjectWarning");
 }
 
+
 // returns true if the path is an ejectable mount point (at the moment CDROM)
 bool KMountMan::ejectable(QString path) {
+#ifndef BSD
   fsData* it;
   for (it=filesystems.first() ; (it!=0) ; it=filesystems.next())
     if (it->mntPoint()==path &&
         (it->type()=="iso9660" || followLink(it->name()).left(2)=="cd"))
       return true;
+#endif
   return false;
 }
 
 ///////////////////////////////////// statsCollector /////////////////////////////////////
+
 statsCollector::statsCollector(QString path, QObject *caller): QObject() {
   QString stats;
   connect(this, SIGNAL(gotStats(QString)), caller, SLOT(gotStats(QString)));
+#ifdef BSD
+  if (path.left(5)=="/procfs") { // /procfs is a special case - no volume information
+    stats=i18n("No space information on a [procfs]");
+#else
   if (path.left(5)=="/proc") { // /proc is a special case - no volume information
     stats=i18n("No space information on a [proc]");
+#endif
     emit gotStats(stats);
     return;
   }
@@ -571,11 +680,14 @@ void statsCollector::parseDf(QString filename, fsData *data) {
   QString s;
   s = t.readLine();  // read the 1st line - it's trash for us
   s = t.readLine();  // this is the important one!
+#ifndef BSD
   data->setName(KMountMan::nextWord(s,' '));
+#endif
   data->setType(KMountMan::nextWord(s,' '));
   data->setTotalBlks( KMountMan::nextWord(s,' ').toLong() );
-  data->setUsedBlks( KMountMan::nextWord(s,' ').toLong() );
-  KMountMan::nextWord(s,' '); KMountMan::nextWord(s,' ');
+  KMountMan::nextWord(s,' ');
+  data->setFreeBlks( KMountMan::nextWord(s,' ').toLong() );
+  KMountMan::nextWord(s,' ');
 	data->setMntPoint(KMountMan::nextWord(s,'\n'));
   data->setMounted(true);
   f.close();
@@ -587,7 +699,11 @@ void statsCollector::getData(QString path, fsData *data) {
   KShellProcess dfProc;
   QString tmpFile = krApp->getTempFile();
 
+#ifdef BSD
+  dfProc << "df" << "\""+path+"\"" << ">" << tmpFile; // FreeBSD: df instead of df -T -P
+#else
   dfProc << "df" << "-T" << "-P" << "\""+path+"\"" << ">" << tmpFile;
+#endif
   dfProc.start(KProcess::Block);
   parseDf(tmpFile, data);
   QDir().remove(tmpFile);
@@ -596,7 +712,7 @@ void statsCollector::getData(QString path, fsData *data) {
 // a mountMan special version of KIO::convertSize, which deals
 // with large filesystems ==> >4GB, it actually recieve size in
 // a minimum block of 1024 ==> data is KB not bytes
-QString KMountMan::convertSize( unsigned long size )
+QString KMountMan::convertSize( KIO::filesize_t size )
 {
     float fsize;
     QString s;
@@ -632,4 +748,3 @@ QString KMountMan::convertSize( unsigned long size )
 }
 
 #include "kmountman.moc"
-
