@@ -35,7 +35,6 @@
 #include "../krusader.h"
 #include "../Dialogs/krspecialwidgets.h"
 #include "../kicons.h"
-#include "../VFS/krdirwatch.h"
 #include "../defaults.h"
 #include <klocale.h>
 #include <qpixmap.h>
@@ -50,13 +49,13 @@
 
 using namespace MountMan;
 
-KMountManGUI::KMountManGUI() : KDialogBase(0,0,true,"Mount.Man"),
+KMountManGUI::KMountManGUI() : KDialogBase(krApp, 0,true,"Mount.Man"),
       info(0), mountList(0) {
-  watcher = new KRdirWatch();
+  watcher = new QTimer(this);
+  connect(watcher,SIGNAL(timeout()), this, SLOT(checkMountChange())); //<>
 
   connect((QObject*)&krMtMan,SIGNAL(updated()),this,SLOT(updateList())); // <>
-  connect(watcher,SIGNAL(dirty()),(QObject*)&krMtMan,SLOT(forceUpdate())); //<>
-  setButtonOKText(i18n("Close"),i18n("Close the Mount.Man window."),0);
+  setButtonOKText(i18n("&Close"),i18n("Close the Mount.Man window."),0);
   showButtonApply(false); showButtonCancel(false);
   setPlainCaption(i18n("MountMan - Your Mount-Manager"));
   widget=new KJanusWidget(this,0,KJanusWidget::Tabbed);
@@ -70,7 +69,7 @@ KMountManGUI::KMountManGUI() : KDialogBase(0,0,true,"Mount.Man"),
   // connections
   connect(mountList,SIGNAL(doubleClicked(QListViewItem *)),this,
           SLOT(doubleClicked(QListViewItem*)));
-  connect(mountList,SIGNAL(rightButtonClicked(QListViewItem *, const QPoint &, int)),
+  connect(mountList,SIGNAL(rightButtonPressed(QListViewItem *, const QPoint &, int)),
           this, SLOT(clicked(QListViewItem*)));
   connect(mountList,SIGNAL(clicked(QListViewItem *)), this,
           SLOT(changeActive(QListViewItem *)));
@@ -80,6 +79,12 @@ KMountManGUI::KMountManGUI() : KDialogBase(0,0,true,"Mount.Man"),
   exec();
 }
 
+KMountManGUI::~KMountManGUI()
+{
+  watcher->stop();
+  delete watcher;
+}
+
 void KMountManGUI::createLayout() {
   mainPage=widget->addPage(i18n("Filesystems"),0);
   createMainPage();
@@ -130,7 +135,6 @@ void KMountManGUI::createMainPage() {
 }
 
 void KMountManGUI::updateList() {
-  createDirwatch();
   fsData *it;
   mountList->clear();
   for (it=krMtMan.filesystems.first(); it!=0 ; it=krMtMan.filesystems.next()) {
@@ -164,14 +168,14 @@ void KMountManGUI::updateList() {
     info->setEmpty(true);
     info->repaint();
   }
-  watcher->startScan();
+  watcher->start( WATCHER_DELAY, true);   // starting the watch timer ( single shot )
 }
 
-void KMountManGUI::createDirwatch() {
-  fsData* it;
-  for (it=krMtMan.filesystems.first(); it!=0 ; it=krMtMan.filesystems.next()) {
-    watcher->addDir(it->mntPoint());
-  }
+void KMountManGUI::checkMountChange()
+{
+  if( krMtMan.checkMtabChanged() )
+    krMtMan.forceUpdate();
+  watcher->start( WATCHER_DELAY, true);   // starting the watch timer ( single shot )
 }
 
 void KMountManGUI::doubleClicked(QListViewItem *i) {
