@@ -35,7 +35,8 @@
 #include "../krusader.h"
 #include "../VFS/vfs.h"
 #include "../krusaderview.h"
-#include "../Panel/kvfspanel.h"
+#include "../Panel/listpanel.h"
+#include "../Panel/panelfunc.h"
 #include "../resources.h"
 #include "../defaults.h"
 #include "../Dialogs/krdialogs.h"
@@ -99,13 +100,15 @@ void qdate2time_t(time_t *dest, QDate d, bool start) {
 
 // class starts here /////////////////////////////////////////
 KrSearchDialog::KrSearchDialog(QWidget *parent, const char *name ) :
-                KrSearchBase(parent,name), searcher(0), query(0) {
+                KrSearchBase(parent,name), query(0), searcher(0) {
   prepareGUI();
   show();
   // disable the search action ... no 2 searchers !
   krFind->setEnabled(false);
   searchFor->setFocus();
 	resultsList->setColumnAlignment(2, AlignRight);
+
+  isSearching = closed = false;
 }
 
 KrSearchDialog::~KrSearchDialog(){
@@ -172,8 +175,7 @@ void KrSearchDialog::prepareGUI() {
   searchIn->clear(); dontSearchIn->clear();
 
 	// the path in the active panel should be the default search location
-	if (krApp->mainView->activePanel->type == "list" &&
-	    krApp->mainView->activePanel->files->vfs_getType() != "ftp") {
+	if (krApp->mainView->activePanel->func->files()->vfs_getType() != "ftp") {
 		QString path = krApp->mainView->activePanel->getPath();
 		// if we're inside an archive, show its directory
 		int i = path.find('\\');
@@ -246,8 +248,11 @@ void KrSearchDialog::addToSearchIn() {
 }
 
 void KrSearchDialog::addToSearchInManually() {
-  searchIn->append(searchInEdit->text());
-  searchInEdit->clear();
+  if( searchInEdit->text().simplifyWhiteSpace().length() )
+  {  
+    searchIn->insertItem(searchInEdit->text());
+    searchInEdit->clear();
+  }
 }
 
 void KrSearchDialog::addToDontSearchIn() {
@@ -258,13 +263,19 @@ void KrSearchDialog::addToDontSearchIn() {
 }
 
 void KrSearchDialog::addToDontSearchInManually() {
-  dontSearchIn->append(dontSearchInEdit->text());
-  dontSearchInEdit->clear();
+  if( dontSearchInEdit->text().simplifyWhiteSpace().length() )
+  {
+    dontSearchIn->insertItem(dontSearchInEdit->text());
+    dontSearchInEdit->clear();
+  }
 }
 
-void KrSearchDialog::found(QString what, QString where, long size, QString date, QString perm){
-  new QListViewItem(resultsList, what, where.replace(QRegExp("\\"),"#"),
-                    KRpermHandler::parseSize(size), date, perm);
+void KrSearchDialog::found(QString what, QString where, KIO::filesize_t size, time_t mtime, QString perm){
+  // convert the time_t to struct tm
+  struct tm* t=localtime((time_t *)&mtime);
+  QDateTime tmp(QDate(t->tm_year+1900, t->tm_mon+1, t->tm_mday), QTime(t->tm_hour, t->tm_min));
+  new QListViewItem(resultsList, what, where.replace(QRegExp("\\\\"),"#"),
+                    KRpermHandler::parseSize(size), KGlobal::locale()->formatDateTime(tmp), perm);
   QString totals = QString("Found %1 matches.").arg(resultsList->childCount());
   foundLabel->setText(totals);
 }
@@ -277,7 +288,6 @@ void KrSearchDialog::query2gui() {
         it != query->matches.end(); ++it )
     tmp += ((tmp == QString::null ? QString::null : QChar(' ')) + (*it));
   searchFor->insertItem(tmp,0);
-  kdWarning() << tmp << endl;
 }
 
 bool KrSearchDialog::gui2query() {
@@ -290,6 +300,7 @@ bool KrSearchDialog::gui2query() {
   if (containsText->isEnabled())
     query->contain = containsText->currentText();
   query->containCaseSensetive = containsTextCase->isChecked();
+  query->containWholeWord     = containsWholeWord->isChecked();
   query->inArchive = searchInArchives->isChecked();
   query->recurse = searchInDirs->isChecked();
   query->followLinks = followLinks->isChecked();
@@ -297,10 +308,24 @@ bool KrSearchDialog::gui2query() {
     query->type = ofType->currentText();
   else query->type = QString::null;
   // create the lists
-  query->whereToSearch = QStringList::split(QChar('\n'), searchIn->text().simplifyWhiteSpace());
+  query->whereToSearch.clear();
+  QListBoxItem *item = searchIn->firstItem();
+  while ( item )
+  {    
+    query->whereToSearch.append( item->text().simplifyWhiteSpace() );
+    item = item->next();
+  }
+
   if (!searchInEdit->text().simplifyWhiteSpace().isEmpty())
     query->whereToSearch.append(searchInEdit->text().simplifyWhiteSpace());
-  query->whereNotToSearch = QStringList::split(QChar('\n'), dontSearchIn->text());
+
+  query->whereNotToSearch.clear();
+  item = dontSearchIn->firstItem();
+  while ( item )
+  {
+    query->whereNotToSearch.append( item->text().simplifyWhiteSpace() );
+    item = item->next();
+  }
   if (!dontSearchInEdit->text().simplifyWhiteSpace().isEmpty())
     query->whereNotToSearch.append(dontSearchInEdit->text().simplifyWhiteSpace());
 
@@ -465,7 +490,7 @@ void KrSearchDialog::startSearch() {
   TabWidget2->setCurrentPage(2); // show the results page
   qApp->processEvents();
 
-  // start the search
+  // start the search.
   if (searcher != 0) {
     delete searcher;
     searcher = 0;
@@ -473,11 +498,15 @@ void KrSearchDialog::startSearch() {
   searcher  = new KRSearchMod(query);
   connect(searcher, SIGNAL(searching(const QString&)),
           searchingLabel, SLOT(setText(const QString&)));
-  connect(searcher, SIGNAL(found(QString,QString,long,QString,QString)),
-                this, SLOT(found(QString,QString,long,QString,QString)));
+  connect(searcher, SIGNAL(found(QString,QString,KIO::filesize_t,time_t,QString)),
+                this, SLOT(found(QString,QString,KIO::filesize_t,time_t,QString)));
   connect(searcher, SIGNAL(finished()), this, SLOT(stopSearch()));
 
+  isSearching = true;
   searcher->start();
+  isSearching = false;
+  if( closed )
+    emit closeDialog();
 }
 
 void KrSearchDialog::stopSearch() {
@@ -523,9 +552,7 @@ void KrSearchDialog::fillList(QComboBox *list, QString filename) {
 }
 
 void KrSearchDialog::resultClicked(QListViewItem* i) {
- 	KVFSPanel *lst = krApp->mainView->activePanel;
- 	if (lst->type != "list") lst = lst->otherPanel;
- 	lst->openUrl((i->text(1)).replace(QRegExp("#"),"\\"),i->text(0));
+ 	krApp->mainView->activePanel->func->openUrl((i->text(1)).replace(QRegExp("#"),"\\")+"/"+i->text(0));
   showMinimized();
 }
 
@@ -535,7 +562,60 @@ void KrSearchDialog::saveSearch() {
 void KrSearchDialog::loadSearch() {
 }
 
-void KrSearchDialog::loadSearch(QListViewItem *i) {
+void KrSearchDialog::loadSearch(QListViewItem *) {
 }
 
+void KrSearchDialog::deleteSelectedItems( QListBox *list_box )
+{
+  int i=0;
+  QListBoxItem *item;
+
+  while( item = list_box->item(i) )
+  {
+    if( item->isSelected() )
+    {
+      list_box->removeItem( i );
+      continue;
+    }
+    i++;
+  }
+}
+
+void KrSearchDialog::closeEvent(QCloseEvent *e)
+{                     /* if searching is in progress we must not close the window */
+  if( isSearching )   /* because qApp->processEvents() is called by the searcher and */
+  {                   /* at window desruction, the searcher object will be deleted */
+    stopSearch();         /* instead we stop searching */
+    closed = true;        /* and after stopping: startSearch can close the window */
+    e->ignore();          /* ignoring the close event */
+  }
+  else
+    QDialog::closeEvent( e );   /* if no searching, let QDialog handle the event */
+}
+
+void KrSearchDialog::keyPressEvent(QKeyEvent *e)
+{
+  if( isSearching && e->key() == Key_Escape ) /* at searching we must not close the window */
+  {
+    stopSearch();         /* so we simply stop searching */
+    return;
+  }
+  else if( e->key() == Key_Delete )
+  {
+    if( searchIn->hasFocus() )
+    {
+      deleteSelectedItems( searchIn );
+      return;
+    }
+    if( dontSearchIn->hasFocus() )
+    {
+      deleteSelectedItems( dontSearchIn );
+      return;
+    }
+  }
+
+  QDialog::keyPressEvent( e );
+}
+
+
 #include "krsearchdialog.moc"
