@@ -46,6 +46,7 @@
 #include <sys/stat.h>
 #include <qtextstream.h>
 #include <qregexp.h>
+#include <klargefile.h>
 
 #include <kmimetype.h>
 
@@ -93,9 +94,9 @@ bool KRSearchMod::checkType(QString mime){
 }
 
 bool KRSearchMod::fileMatch(const QString name){
-	int len;
+	unsigned int len;
 	for(unsigned int i=0; i<query->matches.count(); ++i){
-	  QRegExp(*query->matches.at(i),query->matchesCaseSensitive,true).match(name,0,&len);
+	  QRegExp(*query->matches.at(i),query->matchesCaseSensitive,true).match(name,0,(int*)&len);
     if( len==name.length()) return true;
 	}
   return false;
@@ -127,8 +128,8 @@ void KRSearchMod::scanDir( QString dir){
 		if (name=="." || name == "..") continue;
 		
     url.setPath(dir+name);
-		struct stat stat_p;
-	  lstat(dir.local8Bit()+name.local8Bit(),&stat_p);
+		KDE_struct_stat stat_p;
+	  KDE_lstat(dir.local8Bit()+name.local8Bit(),&stat_p);
  	  if( query->recurse ){
 				if( S_ISLNK(stat_p.st_mode) && query->followLinks ){
             scanDir( QDir(dir+"/"+name).canonicalPath() );
@@ -178,21 +179,43 @@ void KRSearchMod::scanDir( QString dir){
 			QTextStream text(&qf);
       text.setEncoding(QTextStream::Locale);
       QString line;
+      bool found = false;
 			while(!stopSearch && !text.atEnd() ){
         line = text.readLine();
         if (line.isNull() ) break;
-        if (line.find(query->contain, 0, query->containCaseSensetive) != -1)
-         	  break;
+        if ( query->containWholeWord )
+        {
+          int ndx = 0;
+
+          while( ( ndx = line.find(query->contain, ndx, query->containCaseSensetive) ) != -1)
+          {
+            QChar before = line.at( ndx-1 );
+            QChar after  = line.at( ndx + query->contain.length() );
+
+            if( !before.isLetterOrNumber() && !after.isLetterOrNumber() &&
+              after!='_' && before!='_')
+              {
+                found = true;
+                break;
+              }
+            //qApp->processEvents(); // is that needed ?
+            ndx++;
+          }
+        }
+        else if (line.find(query->contain, 0, query->containCaseSensetive) != -1)
+          found = true;
+        
+        if( found )
+          break;
          	//qApp->processEvents(); // is that needed ?
       }
-      if (line.isNull() || text.atEnd() ) continue;
+      if ( !found ) continue;
     }
 
     // if we got here - we got a winner
     results.append(dir+name);
 		//  kdWarning() << "Found: " << (dir+name).local8Bit() << endl;
-    emit found(name, dir, stat_p.st_size, KRpermHandler::time2QString(stat_p.st_mtime),
-               KRpermHandler::mode2QString(stat_p.st_mode) );
+    emit found(name, dir, (KIO::filesize_t)stat_p.st_size, stat_p.st_mtime,KRpermHandler::mode2QString(stat_p.st_mode) );
     qApp->processEvents();
   }
 	// clean up
@@ -228,11 +251,11 @@ void KRSearchMod::scanVfsDir( vfs* v, QString dir, QString archive ){
     // see if the name matches
     if( !fileMatch(name) ) continue;
     // check that the size fit
-    long size = vf->vfile_getSize();
+    KIO::filesize_t size = vf->vfile_getSize();
 		if( query->minSize && size < query->minSize ) continue;
     if( query->maxSize && size > query->maxSize ) continue;
 		// check the time frame
-    time_t mtime = KRpermHandler::QString2time(vf->vfile_getDateTime());
+    time_t mtime = vf->vfile_getTime_t();
 		if( query->olderThen && mtime > query->olderThen ) continue;
     if( query->newerThen && mtime < query->newerThen ) continue;
     // check owner name
@@ -246,7 +269,7 @@ void KRSearchMod::scanVfsDir( vfs* v, QString dir, QString archive ){
 
 		// if we got here - we got a winner
     results.append(dir+name);
-		emit found(name, archive+dir, size, vf->vfile_getDateTime(),vf->vfile_getPerm());
+		emit found(name, archive+dir, size, vf->vfile_getTime_t(),vf->vfile_getPerm());
     qApp->processEvents();
 	}
 }
