@@ -28,8 +28,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <sys/param.h>
 #include <sys/types.h>
 #include <dirent.h>
+#include <time.h>
 // QT includes
 #include <qregexp.h>
 #include <qdir.h>
@@ -42,7 +44,9 @@
 #include <kio/jobclasses.h>
 #include <qprogressdialog.h>
 #include <kglobalsettings.h>
+#include <kmimetype.h>
 #include <kcursor.h>
+#include <klargefile.h>
 // krusader includes
 #include "arc_vfs.h"
 #include "krpermhandler.h"
@@ -63,9 +67,6 @@ arc_vfs::arc_vfs(QString origin,QString type,QObject* panel,bool write):
 	// set the cursor to busy mode
   if (!quietMode) krApp->setCursor(KCursor::waitCursor());
 
-  krConfig->setGroup("Archives");
-  supportMoveTo = krConfig->readBoolEntry("Allow Move Into Archive",_MoveIntoArchive);
-
   // set the writable attribute
 	isWritable = KRpermHandler::fileWriteable(origin);
   isWritable = ( write && isWritable ); 	
@@ -89,10 +90,7 @@ arc_vfs::arc_vfs(QString origin,QString type,QObject* panel,bool write):
     addCmd  = "gzip -c";
     getCmd  = "-dc";
 		ignoreLines = -1;
-    supportCopyTo   = false;
-    supportDelete   = false;
-    supportMoveTo   = false;
-    supportMoveFrom = false;
+		isWritable = false;
   }
   if(type == "zip2"){
     cmd = "bzip2" ;
@@ -101,10 +99,7 @@ arc_vfs::arc_vfs(QString origin,QString type,QObject* panel,bool write):
     addCmd  = "bzip2 -c";
     getCmd  = "-dc";
 		ignoreLines = -1;
-    supportCopyTo   = false;
-    supportDelete   = false;
-    supportMoveTo   = false;
-    supportMoveFrom = false;
+    isWritable = false;
   }
   if(type == "-tar"){
     cmd = "tar" ;
@@ -112,9 +107,6 @@ arc_vfs::arc_vfs(QString origin,QString type,QObject* panel,bool write):
     delCmd  = cmd+" --delete -vf";
     addCmd  = cmd+" -uvf";
     getCmd  = " -xvf";
-    supportCopyTo = true;
-    supportDelete = true;
-		supportMoveTo = false;
   }
 	if(type == "-tgz"){
     cmd = "tar" ;
@@ -122,9 +114,7 @@ arc_vfs::arc_vfs(QString origin,QString type,QObject* panel,bool write):
     delCmd  = "";
     addCmd  = cmd+" -uvzf";
     getCmd  = " -xzvf";
-    supportCopyTo = false;
-    supportDelete = false;
-		supportDelete = false;
+    isWritable = false;
   }
   if(type == "-tbz"){
     cmd = "tar" ;
@@ -132,9 +122,7 @@ arc_vfs::arc_vfs(QString origin,QString type,QObject* panel,bool write):
     delCmd  = "";
     addCmd  = cmd+" -uvjf";
     getCmd  = " -xjvf";
-    supportCopyTo = false;
-    supportDelete = false;
-		supportDelete = false;
+    isWritable = false;
   }
 	if(type == "-zip"){
     password = KRarcHandler::getPassword(arcFile,type);
@@ -151,8 +139,6 @@ arc_vfs::arc_vfs(QString origin,QString type,QObject* panel,bool write):
 			getCmd = getCmd + " -P "+password;
 		}
     ignoreLines = 1;
-    supportCopyTo = true;
-    supportDelete = true;
   }
   // "-rpm" is used only to list the rpm - to extract files use "+rpm"
   if(type == "-rpm"){
@@ -164,9 +150,6 @@ arc_vfs::arc_vfs(QString origin,QString type,QObject* panel,bool write):
     delCmd  = "";
     addCmd  = "";
     getCmd  = "";
-    supportCopyTo = false;
-    supportDelete = false;
-    supportMoveTo = false;
     isWritable    = false;
   }
   if( type == "+rpm" ){
@@ -182,9 +165,6 @@ arc_vfs::arc_vfs(QString origin,QString type,QObject* panel,bool write):
     delCmd  = "";
     addCmd  = "";
     getCmd  = " --force-local --no-absolute-filenames -ivdF";
-    supportCopyTo = false;
-    supportDelete = false;
-    supportMoveTo = false;
     isWritable    = false;
   }
   if(type == "-rar"){
@@ -195,14 +175,9 @@ arc_vfs::arc_vfs(QString origin,QString type,QObject* panel,bool write):
     addCmd  = (doRar ? QString("rar -r a ") : QString("")) ;
     getCmd  = " x -y ";
     ignoreLines = 8;
-    supportMoveFrom = false;
-    supportDelete =  false ;
-    supportCopyTo =  doRar ;
-    supportMoveTo = (doRar && supportMoveTo ) ;
     isWritable    = (doRar && isWritable );
   }
 
-
 	getDirs();
 	// set the cursor to normal mode
   if (!quietMode) krApp->setCursor(KCursor::arrowCursor());
@@ -289,7 +264,7 @@ bool arc_vfs::getDirs(){
 
 
 // copy a file to the vfs (physical)
-void arc_vfs::vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QWidget* toNotify,QString dir){
+void arc_vfs::vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify,QString dir){
   if ( addCmd.isEmpty() ) return;
 
   // get the path inside the archive
@@ -309,9 +284,9 @@ void arc_vfs::vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QWid
 	dest.setPath(tmpDir+path+dir);
 
   KIO::Job* job = new KIO::CopyJob(*fileUrls,dest,mode,false,true);
-  connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh()) );
+  connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh(KIO::Job*)) );
   if(mode == KIO::CopyJob::Move) // notify the other panel
-   connect(job,SIGNAL(result(KIO::Job*)),toNotify,SLOT(refresh()) );
+   connect(job,SIGNAL(result(KIO::Job*)),toNotify,SLOT(vfs_refresh(KIO::Job*)) );
 }
 	
 
@@ -326,7 +301,7 @@ void arc_vfs::vfs_delFiles(QStringList *fileNames){
 	  changed = true;
 	
 	  KIO::Job *job = new KIO::CopyJob(*filesUrls,KGlobalSettings::trashPath(),KIO::CopyJob::Move,false,true );
-	  connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh()));
+	  connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh(KIO::Job*)));
 	}
 	// else we have to delete the files from both the archive and the temp dir
 	else {
@@ -335,7 +310,8 @@ void arc_vfs::vfs_delFiles(QStringList *fileNames){
     chdir(tmpDir.local8Bit());
 
     QStringList files;
-    unsigned long totalSizeVal = 0 , totalFilesVal =  0;
+    KIO::filesize_t totalSizeVal = 0;
+    unsigned long totalFilesVal =  0;
     	
 	  // names -> urls
     for(QStringList::Iterator name = fileNames->begin(); name != fileNames->end(); ++name )
@@ -366,7 +342,7 @@ void arc_vfs::vfs_delFiles(QStringList *fileNames){
 
 	  changed = true;
 	  chdir (save.local8Bit());
-	  vfs_refresh();
+	  vfs_refresh(vfs_origin);
   }
 }	
 
@@ -397,7 +373,8 @@ KURL::List* arc_vfs::vfs_getFiles(QStringList* names){
 	chdir(tmpDir.local8Bit());
 	// names -> urls
   QStringList files;
-  unsigned long totalSize = 0,totalFiles = 0;
+  KIO::filesize_t totalSize = 0;
+  unsigned long totalFiles = 0;
   for(QStringList::Iterator name = names->begin(); name != names->end(); ++name ){
     processName(*name,&files,&totalSize,&totalFiles);
     url.setPath(tmpDir+"/"+path+(*name));
@@ -449,7 +426,7 @@ void arc_vfs::vfs_mkdir(QString name){
 
   QDir(tmpDir).mkdir(path+name);
   changed = true; //rescan the archive
-  vfs_refresh();
+  vfs_refresh(vfs_origin);
 }
 	
 // rename file
@@ -467,7 +444,7 @@ void arc_vfs::vfs_rename(QString fileName,QString newName){
 	dest.setPath(tmpDir+path+"/"+newName);
 
   KIO::Job* job = new KIO::CopyJob(temp,dest,KIO::CopyJob::Move,false,false);
-  connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh()) );
+  connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh(KIO::Job*)) );
 }
 
 bool arc_vfs::vfs_refresh(QString origin){
@@ -517,11 +494,11 @@ void arc_vfs::getFilesToPack(QStringList* filesToPack,QString dir_name){
 
 	register struct dirent* dirEnt;
   QString name;
-	struct stat stat_p;
+	KDE_struct_stat stat_p;
 	while( (dirEnt=readdir(dir)) != NULL ){
     name = dirEnt->d_name;
 		if ( name == ".." || name == "." ) continue;
-	  if( lstat(tmpDir.local8Bit()+"/"+dir_name.local8Bit()+name.local8Bit(),&stat_p) ) continue;
+	  if( KDE_lstat(tmpDir.local8Bit()+"/"+dir_name.local8Bit()+name.local8Bit(),&stat_p) ) continue;
 	  extFile temp(dir_name+name,stat_p.st_mtime,stat_p.st_size);
 		// add to the list file that are diffrent than the ones packed
     if( S_ISDIR(stat_p.st_mode) ){ // recurse on all sub dirs
@@ -548,7 +525,7 @@ void arc_vfs::getFilesToPack(QStringList* filesToPack,QString dir_name){
   vfs_filesP = vfs_filesP_backup; // restore  vfs_filesP
 }
 
-void arc_vfs::getFilesToDelete(QStringList* filesToDelete,QString dir_name){
+void arc_vfs::getFilesToDelete(QStringList* filesToDelete,QString){
 	// sync the extFiles - and find out which files were deleted
 	QString file;
 	for(unsigned int i=0 ; i<extFiles.count(); ){
@@ -572,11 +549,11 @@ void arc_vfs::getExtFiles(QString dir_name){
 	
 	register struct dirent* dirEnt;
   QString name;
-	struct stat stat_p;
+	KDE_struct_stat stat_p;
 	while( (dirEnt=readdir(dir)) != NULL ){
     name = dirEnt->d_name;
 		if ( name == ".." || name == "." ) continue;
-	  if( lstat(tmpDir.local8Bit()+"/"+dir_name.local8Bit()+name.local8Bit(),&stat_p) ) continue;
+	  if( KDE_lstat(tmpDir.local8Bit()+"/"+dir_name.local8Bit()+name.local8Bit(),&stat_p) ) continue;
 	  extFile temp(dir_name+name,stat_p.st_mtime,stat_p.st_size);
 		// recurse on all sub dirs
     if( S_ISDIR(stat_p.st_mode) ){
@@ -595,7 +572,7 @@ void arc_vfs::repack(){
   chdir(tmpDir.local8Bit());
 	
   // delete from the archive files that were unpacked and deleted
-	if( supportDelete && isWritable){
+	if( vfs_isWritable() ){
 		QStringList filesToDelete;
 		getFilesToDelete(&filesToDelete);
 		if( !filesToDelete.isEmpty() ){
@@ -619,7 +596,7 @@ void arc_vfs::repack(){
 	}
 
   // finaly repack tmpDir
-  if( isWritable || vfs_type=="gzip" || vfs_type=="zip2" ){
+  if( vfs_isWritable() || vfs_type=="gzip" || vfs_type=="zip2" ){
     QStringList filesToPack;
 		getFilesToPack(&filesToPack);
 		if( !filesToPack.isEmpty() ){
@@ -685,7 +662,7 @@ QString arc_vfs::changeDir(QString name){
    if(Pname.isEmpty()) return name;
    QString tempName = arcFile;
    QFileInfo qfi(tempName.replace(QRegExp("\\"),""));
-   vfile* vf=new vfile(Pname,0,"drwxr-xr-x",dateTime2QString(qfi.lastModified()),false,
+   vfile* vf=new vfile(Pname,0,"drwxr-xr-x",qfi.lastModified().toTime_t(),false,
                  qfi.owner(),qfi.group(),"inode/directory","",0 );
    // add  dirs if needed
    changeDir(path);
@@ -702,7 +679,8 @@ QString arc_vfs::changeDir(QString name){
 }
 
 // calculate space
-void arc_vfs::vfs_calcSpace(QString name ,long long *totalSize,long *totalFiles, long *totalDirs){
+void arc_vfs::vfs_calcSpace(QString name ,KIO::filesize_t *totalSize,unsigned long *totalFiles,unsigned long *totalDirs,bool* stop){
+  if (stop && *stop) return;
   vfile* vf = vfs_search(name);
 
   // get the path inside the archive
@@ -723,15 +701,17 @@ void arc_vfs::vfs_calcSpace(QString name ,long long *totalSize,long *totalFiles,
     vfs_filesP = findDir(path+name);
 
     // process all the files in the directory.
-    for( vf = vfs_getFirstFile(); vf != 0; vf = vfs_getNextFile() )
-      vfs_calcSpace(vf->vfile_getName(),totalSize,totalFiles,totalDirs);
-
+    for( vf = vfs_getFirstFile(); vf != 0; vf = vfs_getNextFile() ){
+      if (stop && *stop) return;
+      vfs_calcSpace(vf->vfile_getName(),totalSize,totalFiles,totalDirs,stop);
+    }
+    
     vfs_origin = origin_backup;     // restore origin
     vfs_filesP = vfs_filesP_backup; // restore vfs_filesP
   }
 }
 
-void arc_vfs::processName(const QString& name, QStringList *urls,unsigned long *totalSize,unsigned long *totalFiles ){
+void arc_vfs::processName(const QString& name, QStringList *urls,KIO::filesize_t *totalSize,unsigned long *totalFiles ){
   vfile* vf = vfs_search(name);
 	if ( vf == 0 ) return;
 
@@ -762,21 +742,21 @@ void arc_vfs::processName(const QString& name, QStringList *urls,unsigned long *
 
 void arc_vfs::parseLine(QString line, QFile* temp){
   QString name;
-  long size;
+  KIO::filesize_t size = 0;
   QString perm;
-  QString dateTime;
+  QFileInfo qfi(arcFile);
+  time_t mtime = qfi.lastModified().toTime_t();
   bool link = false;
   uid_t owner = getuid();
   gid_t group = getgid();
   QString dest = "";
-  long mode = 0;
+  mode_t mode = 0;
 
 
   // parse gziped files
   if(vfs_type == "gzip"){
-    QFileInfo qfi(arcFile);
-    struct stat stat_p;
-    stat(arcFile.local8Bit(),&stat_p);
+    KDE_struct_stat stat_p;
+    KDE_stat(arcFile.local8Bit(),&stat_p);
 
     nextWord(line);
     size = nextWord(line).toLong();
@@ -784,7 +764,6 @@ void arc_vfs::parseLine(QString line, QFile* temp){
     name = nextWord(line,'\n');
     if(name.contains('/')) name = name.mid(name.findRev('/')+1,name.length());
     perm  = KRpermHandler::mode2QString(stat_p.st_mode) ;
-    dateTime = dateTime2QString(qfi.lastModified());
     owner = KRpermHandler::user2uid(qfi.owner());
     group = KRpermHandler::group2gid(qfi.group());
     mode  = stat_p.st_mode;
@@ -792,15 +771,13 @@ void arc_vfs::parseLine(QString line, QFile* temp){
 
   // parse bzip2ed files
   if( vfs_type == "zip2" ){
-    QFileInfo qfi(arcFile);
-    struct stat stat_p;
-    stat(arcFile.local8Bit(),&stat_p);
+    KDE_struct_stat stat_p;
+    KDE_stat(arcFile.local8Bit(),&stat_p);
 
     name = qfi.fileName();
     name = name.left(name.findRev('.'));
     //long size = qfi.size();
     perm  = KRpermHandler::mode2QString(stat_p.st_mode) ;
-    dateTime = dateTime2QString(qfi.lastModified());
     owner = KRpermHandler::user2uid(qfi.owner());
     group = KRpermHandler::group2gid(qfi.group());
     mode  = stat_p.st_mode;
@@ -814,9 +791,9 @@ void arc_vfs::parseLine(QString line, QFile* temp){
     group = temp.mid(temp.find('/')+1,temp.length()).toInt();
     size = nextWord(line).toLong();
     temp = nextWord(line);
-    dateTime = temp.mid(8,2)+"/"+temp.mid(5,2)+"/"+temp.mid(2,2)+
-                       " "+nextWord(line).left(5);
     name = nextWord(line,'\n');
+    if (name.startsWith("/"))  // fix full-paths problem in tar (thanks to Heiner!)
+      name.remove(0, 1);
     if( name.contains(" -> ") ){
       link = true;
 			dest = name.mid(name.find(" -> ")+4);
@@ -834,8 +811,6 @@ void arc_vfs::parseLine(QString line, QFile* temp){
     size = nextWord(line).toLong();
     nextWord(line);nextWord(line);
     QString temp = nextWord(line);
-    dateTime = temp.mid(6,2)+"/"+temp.mid(4,2)+"/"+temp.mid(2,2)+
-                       " "+temp.mid(9,2)+":"+temp.mid(11,2);
     name = nextWord(line,'\n');
   }
 
@@ -847,7 +822,6 @@ void arc_vfs::parseLine(QString line, QFile* temp){
 		nextWord(line);nextWord(line);nextWord(line);
 		QString tempName = arcFile;
     QFileInfo qfi(tempName.replace(QRegExp("\\"),""));
-    dateTime = dateTime2QString(qfi.lastModified()) ;
 		name = nextWord(line,'\n');
     if ( name.left(1) == "/" ) name.remove(0,1);
     if( name.contains(" -> ") ){
@@ -863,7 +837,6 @@ void arc_vfs::parseLine(QString line, QFile* temp){
     size = nextWord(line).toLong();
     nextWord(line);
     nextWord(line);
-    dateTime = nextWord(line).replace(QRegExp("-"),"/")+" "+nextWord(line);
     perm = nextWord(line);
     if(perm.length() != 10)
       perm = (perm.at(1)=='D')? "drwxr-xr-x" : "-rw-r--r--" ;
@@ -873,8 +846,7 @@ void arc_vfs::parseLine(QString line, QFile* temp){
 		name = nextWord(line);
     if ( name.left(1) == "/" ) name.remove(0,1);
     size = nextWord(line).toLong();
-    long time = nextWord(line).toLong();
-    dateTime = KRpermHandler::time2QString(time);
+    mtime = nextWord(line).toLong();
     nextWord(line);
     perm = KRpermHandler::mode2QString(nextWord(line).toLong());
     perm = (perm.at(0)=='d')? "drwxr-xr-x" : "-rw-r--r--" ;
@@ -886,7 +858,7 @@ void arc_vfs::parseLine(QString line, QFile* temp){
 
 
   QString mime = KMimeType::findByURL( "/"+name,0,true,true)->name();
-  vfile* vf=new vfile(name,size,perm,dateTime,link,owner,group,mime,dest,mode);
+  vfile* vf=new vfile(name,size,perm,mtime,link,owner,group,mime,dest,mode);
   vfile* vf2 = vfs_search(name);
   if(vf2 != 0) vfs_removeFromList(vf2);
   vfs_addToList(vf);
