@@ -28,10 +28,12 @@
  *                                                                         *
  ***************************************************************************/
 
-
+// Sys includes
+#include <time.h>
 // QT includes
 #include <qdir.h>
 #include <qregexp.h>
+#include <qtimer.h>
 // KDE includes
 #include <kmimetype.h>
 #include <kio/jobclasses.h>
@@ -56,84 +58,98 @@ template <class X> void kr_swap(X &a, X &b){
 }
 
 ftp_vfs::ftp_vfs(QString origin,QWidget* panel):vfs(panel){
-  supportCopyTo = true;
-  supportMoveFrom = true;     // the big 4 is supported by ftp vfs...
-	supportDelete = true;
-	supportMoveTo = true;
-	// set the writable attribute
-	isWritable = true;
-// 	  kdDebug() << origin << endl;
+  // set the writable attribute
+  isWritable = true;
+
   vfs_filesP = &vfs_files;
   vfs_files.setAutoDelete(true);
   vfs_filesP2 = &vfs_files2;
   vfs_files2.setAutoDelete(true);
   notConnected = true;
-		
-	// breakdown the url;
-	/* FIXME: untill KDE fixes the bug we have to check for
-     passwords with @ in them... */
-	bool bugfix = origin.find("@") != origin.findRev("@");
-	if(bugfix) origin[origin.find("@")] = '^';
-	KURL url = origin;
-	port = url.port();
-	loginName = url.user();
-	password = url.pass();
-	if(bugfix){
-		password[password.find('^')] = '@';
-		url.setPass(password);
-	}
-	
 
-	vfs_type = "ftp";
-  vfs_origin = url.prettyURL(-1);
+  KURL url = separateUserAndPassword( origin );
 
-  vfs_refresh();	
+  vfs_type = "ftp";
+  vfs_origin = url.prettyURL();
+
+  vfs_refresh(vfs_origin);
 }
 
-void ftp_vfs::slotAddFiles(KIO::Job * job, const KIO::UDSEntryList& entries){
-	
-	if(vfs_origin.right(1) == "/" ) vfs_origin = vfs_origin.left(vfs_origin.length()-1);
+KURL ftp_vfs::separateUserAndPassword( QString origin )
+{
+  // breakdown the url;
+  /* FIXME: untill KDE fixes the bug we have to check for
+     passwords and users with @ in them... */
+  bool bugfix = origin.find("@") != origin.findRev("@");
+  if(bugfix){
+    if(origin.find(":") != origin.findRev(":")){
+      int passStart = origin.find( ":",origin.find(":")+1 )+1;
+      int passLen = origin.findRev("@")-passStart;
+      password = origin.mid(passStart,passLen);
+      origin = origin.remove(passStart-1,passLen+1);
+    }
+    if(origin.find("@") != origin.findRev("@")){
+      int usrStart = origin.find( "/" )+1;
+      if(origin.at(usrStart) == '/') ++usrStart;
+      int usrLen = origin.findRev("@")-usrStart;
+      loginName = origin.mid(usrStart,usrLen);
+      origin = origin.remove(usrStart,usrLen+1);
+    }
+  }
+  KURL url = origin;
+  port = url.port();
+  if(loginName.isEmpty()) loginName = url.user();
+  if(password.isEmpty())  password  = url.pass();
+  if(bugfix){
+   url.setPass(password);
+    url.setUser(loginName);
+  }
+  
+  return url;
+}
+
+void ftp_vfs::slotAddFiles(KIO::Job *, const KIO::UDSEntryList& entries){
+  // remove trailing "/"
+  if(vfs_origin.right(1) == "/" ) vfs_origin = vfs_origin.left(vfs_origin.length()-1);
+  // but don't turn ftp://server/ to ftp://server !
+  if(vfs_origin.find("/",vfs_origin.find(":/")+3) < 0 )
+		vfs_origin = vfs_origin+"/";
 
   KIO::UDSEntryListConstIterator it = entries.begin();
   KIO::UDSEntryListConstIterator end = entries.end();
 
   // as long as u can find files - add them to the vfs
   for ( ; it != end; ++it ){
-    KFileItem kfi(*it,vfs_url,true,true);
-  	ftp_vfile *temp;
-		
+    KFileItem kfi(*it,vfs_url,false,true);
+    vfile *temp;
+
     // get file statistics
-		QString name=kfi.text();
+    QString name=kfi.text();
     // ignore un-needed entries
-		if (name.isEmpty() || name=="." || name == ".." ) continue;
-	
-		unsigned long size = kfi.size();
-  	QString perm = KRpermHandler::perm2QString(&kfi);
-		QString	dateTime = KRpermHandler::time2QString(kfi.time(256 | 4 | 2));
-		bool symLink = kfi.isLink();
-		uid_t owner= 0;
-		gid_t group= 0;
-		mode_t mode = kfi.mode();
-		QString mime; // set the mimetype
-		if( kfi.isDir() ) mime = "inode/directory";
-		else mime = KMimeType::findByURL( kfi.url(),mode,false,true)->name();
-		QString symDest = "";
-		if(symLink)symDest= kfi.linkDest();
+    if (name.isEmpty() || name=="." || name == ".." ) continue;
+
+    KIO::filesize_t size = kfi.size();
+    time_t mtime = kfi.time(KIO::UDS_MODIFICATION_TIME);
+    bool symLink = kfi.isLink();
+    mode_t mode = kfi.mode() | kfi.permissions();
+    QString perm = KRpermHandler::mode2QString(mode);
+    // set the mimetype
+    QString mime = kfi.mimetype(); 
+    QString symDest = "";
+		if(symLink)symDest = kfi.linkDest();
 		// create a new virtual file object
-  	temp=new ftp_vfile(name,size,perm,dateTime,symLink,owner,group,mime,symDest,mode);
-  	// set the ftp file permissions
-  	temp->setWrite(KRpermHandler::ftpWriteable (kfi.user(),loginName,perm));
-  	temp->setRead (KRpermHandler::ftpReadable  (kfi.user(),loginName,perm));
-  	temp->setExec (KRpermHandler::ftpExecutable(kfi.user(),loginName,perm));
-  	
-  	vfs_addToList(temp);
+    if( kfi.user().isEmpty() )
+      temp=new vfile(name,size,perm,mtime,symLink,getuid(),getgid(),mime,symDest,mode);
+    else
+      temp=new vfile(name,size,perm,mtime,symLink,kfi.user(),kfi.group(),mime,symDest,mode);
+    vfs_addToList(temp);
 	}
 }
 
 void ftp_vfs::slotRedirection(KIO::Job *, const KURL &url){
   // update the origin
   vfs_url    = url;
-	vfs_origin = KURL::decode_string(url.prettyURL(-1));
+	vfs_origin = KURL::decode_string(url.prettyURL());
   password   = url.pass();
   loginName  = url.user();
 	port       = url.port();
@@ -167,19 +183,13 @@ void ftp_vfs::slotListResult(KIO::Job *job){
 
 bool ftp_vfs::vfs_refresh(QString origin) {
 	error = false;
-	KURL url = origin;
-
-	kdDebug() << "Origin = " << origin << endl;
-
-  if( !loginName.isEmpty()) url.setUser(loginName);
-	if( !password.isEmpty() ) url.setPass(password);
-	//if( port ) url.setPort(port);
+	KURL url = separateUserAndPassword( origin );
 
 	QString errorMsg = QString::null;	
 	if ( url.isMalformed() )
     errorMsg = i18n("Malformed URL:\n%1").arg(url.url());
   if( !KProtocolInfo::supportsListing(url) )
-		errorMsg = i18n("Protocol not supported by Krusader:\n").arg(url.url());
+		errorMsg = i18n("Protocol not supported by Krusader:\n%1").arg(url.url());
 
 	if( !errorMsg.isEmpty() ){
     if (!quietMode) KMessageBox::sorry(krApp, errorMsg);
@@ -187,6 +197,9 @@ bool ftp_vfs::vfs_refresh(QString origin) {
     return false;
 	}
 
+  if( !loginName.isEmpty()) url.setUser(loginName);
+  if( !password.isEmpty() ) url.setPass(password);
+  
   // clear the the list and back up out current situation
 	vfs_filesP2->clear();
   kr_swap(vfs_filesP2,vfs_filesP);
@@ -194,9 +207,9 @@ bool ftp_vfs::vfs_refresh(QString origin) {
   vfs_origin = origin;
   vfs_url_backup = vfs_url;
   vfs_url = url;
-		
-	// Open the directory	marked by origin
-	krConfig->setGroup("Look&Feel");
+
+  // Open the directory	marked by origin
+  krConfig->setGroup("Look&Feel");
   KIO::Job *job = new KIO::ListJob(url,false,false,QString::null,
                       krConfig->readBoolEntry("Show Hidden",_ShowHidden));
   connect(job,SIGNAL(entries(KIO::Job*,const KIO::UDSEntryList&)),
@@ -213,7 +226,7 @@ bool ftp_vfs::vfs_refresh(QString origin) {
 
 
 // copy a file to the vfs (physical)	
-void ftp_vfs::vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QWidget* toNotify,QString dir){
+void ftp_vfs::vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify,QString dir){
   KURL destUrl = vfs_url;
   if(dir != "") destUrl.addPath(dir);
 
@@ -223,9 +236,9 @@ void ftp_vfs::vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QWid
   if ( port ) destUrl.setPort(port);
 	
   KIO::Job* job = new KIO::CopyJob(*fileUrls,destUrl,mode,false,true );
-  connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh()) );
+  connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh(KIO::Job*)) );
   if(mode == KIO::CopyJob::Move) // notify the other panel
-    connect(job,SIGNAL(result(KIO::Job*)),toNotify,SLOT(refresh()) );
+    connect(job,SIGNAL(result(KIO::Job*)),toNotify,SLOT(vfs_refresh(KIO::Job*)) );
 }
 
 // remove a file from the vfs (physical)
@@ -244,7 +257,7 @@ void ftp_vfs::vfs_delFiles(QStringList *fileNames){
     filesUrls.append( url );
 	}
 	KIO::Job *job = new KIO::DeleteJob(filesUrls, false, true);
-	connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh()));
+	connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh(KIO::Job*)));
 }
 
 
@@ -266,10 +279,7 @@ KURL::List* ftp_vfs::vfs_getFiles(QStringList* names){
 QString ftp_vfs::vfs_getFile(QString name){	
 	KURL url = vfs_url;
 	
-	if (vfs_search(name)->vfile_isDir())
-		url.addPath(name+"/");
-	else
-	  url.addPath(name);
+  url.addPath(name);
 
 	url.setUser(loginName);
   url.setPass(password);
@@ -286,7 +296,7 @@ void ftp_vfs::vfs_mkdir(QString name){
   if ( port ) url.setPort(port);
 
 	KIO::SimpleJob* job = KIO::mkdir(url);
-	connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh()));
+	connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh(KIO::Job*)));
 }
 
 
@@ -300,13 +310,13 @@ void ftp_vfs::vfs_rename(QString fileName,QString newName){
   fileUrls.append(url);
 
 	KURL dest = vfs_url;
-	dest.setPath(newName);
+	dest.addPath(newName);
 	dest.setUser(loginName);
   dest.setPass(password);
 	if ( port ) dest.setPort(port);
 
   KIO::Job *job = new KIO::CopyJob(fileUrls,dest,KIO::CopyJob::Move,false,true );
-	connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh()));
+	connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh(KIO::Job*)));
 }
 
 QString ftp_vfs::vfs_workingDir(){
