@@ -45,7 +45,7 @@ public:
  ~ftp_vfs(){}
 	
 	// copy a file to the vfs (physical)
-	void    vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QWidget* toNotify,QString dir = "");
+	void    vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify,QString dir = "");
 	// remove a file from the vfs (physical)
 	void 		vfs_delFiles(QStringList *fileNames);	
 	// return a path to the file
@@ -57,7 +57,7 @@ public:
 	void vfs_rename(QString fileName,QString newName);
 	QString vfs_workingDir();
 	// not implemented for ftp !
-	void vfs_calcSpace(QString ,long long *,long *, long *){}
+	void vfs_calcSpace(QString ,KIO::filesize_t *,unsigned long *,unsigned long *,bool*){}
 	
 public slots:
 	// recieve KDirLister  job.
@@ -66,7 +66,6 @@ public slots:
   void slotListResult(KIO::Job *job);
 	// actually reads files and stats
 	bool vfs_refresh(QString origin);
-	inline  void vfs_refresh(){vfs_refresh(vfs_origin);}
 
 protected:
 	QList<vfile>  vfs_files;    // list of pointers to vfile
@@ -82,7 +81,10 @@ protected:
   QString loginName;
 	QString password;
 	QString hostName;
-	int port;  		
+	int port;
+
+private:
+  KURL separateUserAndPassword( QString origin );
 };
 
 #endif
