@@ -31,7 +31,9 @@
 #include <strings.h>
 #endif
 
+#include <sys/stat.h>
 #include <sys/types.h>
+#include <unistd.h>
 #include <dirent.h>
 // QT includes
 #include <qdir.h>
@@ -42,6 +44,8 @@
 #include <kio/jobclasses.h>
 #include <klocale.h>
 #include <kglobalsettings.h>
+#include <kdebug.h>
+#include <klargefile.h>
 // Krusader includes
 #include "normal_vfs.h"
 #include "../Dialogs/krdialogs.h"
@@ -52,37 +56,33 @@
 #include "../resources.h"
 
 normal_vfs::normal_vfs(QString,QWidget* panel):vfs(panel){
-  supportCopyTo = true;
-  supportMoveFrom = true;     // the big 4 is supported by normal vfs...
- 	supportDelete = true;
- 	supportMoveTo = true;
- 	
- 	writeableBase = true;
- 	
   vfs_filesP = &vfs_files;
   vfs_files.setAutoDelete(true);
 	
 	vfs_type="normal";
 	
 	// connect the watcher to vfs_refresh
-  connect(&watcher,SIGNAL(dirty()),this,SLOT(vfs_refresh()));
+  //connect(&watcher,SIGNAL(dirty(const QString&)),this,SLOT(vfs_refresh()));
+  connect(&watcher,SIGNAL(dirty(const QString&)),this,SLOT(vfs_slotDirty()));
 }
 
 bool normal_vfs::vfs_refresh(QString origin){
-  krConfig->setGroup("Advanced");
-  if (krConfig->readBoolEntry("AutoMount",_AutoMount)) krMtMan.autoMount(origin);
-	
-	watcher.stopScan(); //stop watching the old dir
-	watcher.clearList();
-	
 	// check that the new origin exists
 	if ( !QDir(origin).exists() ) return false;
-	
-	// set the writable attribute
-	if( getgid()==0 ) isWritable = true;
-	else isWritable = KRpermHandler::fileWriteable(origin);
-	// we use "writeableBase" to make the vfs not writable on every refresh
-	isWritable = isWritable && writeableBase;
+    
+  krConfig->setGroup("Advanced");
+  if (krConfig->readBoolEntry("AutoMount",_AutoMount)) krMtMan.autoMount(origin);
+   	
+	watcher.stopScan(); //stop watching the old dir
+  if( origin != vfs_getOrigin() ){
+		watcher.removeDir(vfs_getOrigin()); // and remove it from the list
+		watcher.addDir(origin/*,true*/); //start watching the new dir
+	}
+	//watcher.clearList();
+
+	// set the writable attribute to true, if that's not the case - the KIO job
+  // will give the warnings and errors
+	isWritable = true;
 	
  	krConfig->setGroup("Look&Feel");
 	bool hidden = krConfig->readBoolEntry("Show Hidden",_ShowHidden);
@@ -97,6 +97,9 @@ bool normal_vfs::vfs_refresh(QString origin){
 	DIR* dir = opendir(origin.local8Bit());
   if(!dir) return false;
 
+  // change directory to the new directory
+  chdir(origin.local8Bit());
+  
 	if (!quietMode) emit startUpdate();
 	
 	struct dirent* dirEnt;
@@ -104,7 +107,7 @@ bool normal_vfs::vfs_refresh(QString origin){
 	KURL mimeUrl;
 	//int i = 0;
   char symDest[256];
-  struct stat stat_p;
+  KDE_struct_stat stat_p;
 	while( (dirEnt=readdir(dir)) != NULL ){
     name = QString::fromLocal8Bit(dirEnt->d_name);
 
@@ -113,10 +116,9 @@ bool normal_vfs::vfs_refresh(QString origin){
 		// we dont need the ".",".." enteries
 		if (name=="." || name == "..") continue;
 	  	
-	  lstat(vfs_workingDir().local8Bit()+"/"+name.local8Bit(),&stat_p);
-	  unsigned long size = stat_p.st_size;
+	  KDE_lstat(vfs_workingDir().local8Bit()+"/"+name.local8Bit(),&stat_p);
+	  KIO::filesize_t size = stat_p.st_size;
     QString perm = KRpermHandler::mode2QString(stat_p.st_mode);
-    QString	dateTime=KRpermHandler::time2QString(stat_p.st_mtime);
 	  bool symLink= S_ISLNK(stat_p.st_mode);
 	  if( S_ISDIR(stat_p.st_mode) ) perm[0] = 'd';
 	
@@ -136,7 +138,7 @@ bool normal_vfs::vfs_refresh(QString origin){
 	  }
 	  	
 	  // create a new virtual file object
-    vfile* temp=new vfile(name,size,perm,dateTime,symLink,stat_p.st_uid,
+    vfile* temp=new vfile(name,size,perm,stat_p.st_mtime,symLink,stat_p.st_uid,
                           stat_p.st_gid,mime,symDest,stat_p.st_mode);
     vfs_addToList(temp);
   }
@@ -144,14 +146,13 @@ bool normal_vfs::vfs_refresh(QString origin){
 	closedir(dir);
 	
 	if (!quietMode) emit endUpdate();
-  watcher.addDir(origin); //start watching the new dir
   watcher.startScan();
 
   return true;
 }
 
 // copy a file to the vfs (physical)	
-void normal_vfs::vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QWidget* toNotify,QString dir){
+void normal_vfs::vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify,QString dir){
   watcher.stopScan(); // we will refresh manually this time...	
 
 	KURL dest;
@@ -160,7 +161,7 @@ void normal_vfs::vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,Q
   KIO::Job* job = new KIO::CopyJob(*fileUrls,dest,mode,false,true );
   connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh()) );
   if(mode == KIO::CopyJob::Move) // notify the other panel
-    connect(job,SIGNAL(result(KIO::Job*)),toNotify,SLOT(refresh()) );
+    connect(job,SIGNAL(result(KIO::Job*)),toNotify,SLOT(vfs_refresh(KIO::Job*)) );
 }
 
 // remove a file from the vfs (physical)
@@ -190,7 +191,7 @@ void normal_vfs::vfs_delFiles(QStringList *fileNames){
 	else
 	  job = new KIO::DeleteJob(filesUrls, false, true);
 	
-	connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh()));
+	connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh(KIO::Job*)));
 }
 
 // return a path to the file
@@ -212,7 +213,7 @@ KURL::List* normal_vfs::vfs_getFiles(QStringList* names){
 void normal_vfs::vfs_mkdir(QString name){
 	if (!QDir(vfs_workingDir()).mkdir(name))
 	  if (!quietMode) KMessageBox::sorry(krApp,i18n("Can't create a directory check your permissions."));
-	else vfs_refresh();
+  vfs_refresh(vfs_origin);
 }
 
 
@@ -227,10 +228,11 @@ void normal_vfs::vfs_rename(QString fileName,QString newName){
 	dest.setPath(vfs_workingDir()+"/"+newName);
 
   KIO::Job *job = new KIO::CopyJob(fileUrls,dest,KIO::CopyJob::Move,false,false );
-	connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh()));
+	connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh(KIO::Job*)));
 }
 
-void normal_vfs::vfs_calcSpace(QString name ,long long *totalSize,long *totalFiles, long *totalDirs){
+void normal_vfs::vfs_calcSpace(QString name ,KIO::filesize_t *totalSize,unsigned long *totalFiles,unsigned long *totalDirs, bool* stop){
+  if (stop && *stop) return;
   if (!name.contains("/")) name = vfs_workingDir()+"/"+name;
   if (name == "/proc") return;
 
@@ -250,8 +252,9 @@ void normal_vfs::vfs_calcSpace(QString name ,long long *totalSize,long *totalFil
 	  // recurse on all the files in the directory
 	  QFileInfoList* fileList = const_cast<QFileInfoList*>(dir.entryInfoList());
 	  for (QFileInfo* qfiP = fileList->first(); qfiP != 0; qfiP = fileList->next()){
-	    if (qfiP->fileName() != "." && qfiP->fileName() != "..")
-	      vfs_calcSpace(name+"/"+qfiP->fileName(),totalSize,totalFiles,totalDirs);
+      if (stop && *stop) return;
+      if (qfiP->fileName() != "." && qfiP->fileName() != "..")
+	      vfs_calcSpace(name+"/"+qfiP->fileName(),totalSize,totalFiles,totalDirs,stop);
 	  }
   }
 }
