@@ -37,9 +37,10 @@
 #include <qstring.h>
 // KDE includes
 #include <kfileitem.h>
+#include <kdirwatch.h>
 // Krusader includes
 #include "vfs.h"
-#include "krdirwatch.h"
+//#include "krdirwatch.h"
 
 class normal_vfs : public vfs{
 	Q_OBJECT
@@ -49,7 +50,7 @@ public:
  ~normal_vfs(){}
 	
 	// copy a file to the vfs (physical)
-	void    vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QWidget* toNotify=0,QString dir="");	
+	void    vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify=0,QString dir="");	
 	// remove a file from the vfs (physical)
 	void 		vfs_delFiles(QStringList *fileNames);	
 	// return a path to the file
@@ -60,7 +61,7 @@ public:
 	// rename file
 	void vfs_rename(QString fileName,QString newName);
 	// calculate space
-	void vfs_calcSpace(QString name ,long long *totalSize,long *totalFiles, long *totalDirs);
+	void vfs_calcSpace(QString name ,KIO::filesize_t *totalSize,unsigned long *totalFiles,unsigned long *totalDirs, bool * stop = 0);
 	// return the working dir
 	inline virtual QString vfs_workingDir() { return vfs_origin; }
 	void blockSignals(bool block){ block? watcher.stopScan() : watcher.startScan() ; }
@@ -68,12 +69,11 @@ public:
 public slots:
 	// actually reads files and stats
 	bool vfs_refresh(QString origin);
-  inline  bool vfs_refresh(){ return vfs_refresh(vfs_origin);}
+  void vfs_slotDirty(){ QTimer::singleShot(100,this,SLOT(vfs_refresh())); }
 
 protected:
 	QList<vfile>  vfs_files;    // list of pointers to vfile	
-	KRdirWatch watcher;
-  bool writeableBase;
+	KDirWatch watcher;
 };
 
 #endif
