@@ -39,9 +39,8 @@
 #include "../VFS/krarchandler.h"
 #include "../resources.h"
 
-temp_vfs::temp_vfs( QString origin, QString type, QWidget* panel, bool writeable ):
+temp_vfs::temp_vfs( QString origin, QString type, QWidget* panel, bool ):
           normal_vfs(origin,panel){
-
   vfs_type="temp";
   // first we need to create a temp diretory
 	tmpDir = krApp->getTempDir();
@@ -49,18 +48,14 @@ temp_vfs::temp_vfs( QString origin, QString type, QWidget* panel, bool writeable
     error = true;
     return;
   }
-	
-	supportCopyTo = false;       //
-  supportMoveFrom = false;     // the big 4 is NOT supported by default.
- 	supportDelete = false;       // we can always change that later on...
- 	supportMoveTo = false;       //
- 	writeableBase = false;       //
 
-// then we must get the files from the origin to the tmp dir
+	// then we must get the files from the origin to the tmp dir
   if( type == "-arj" || type == "-ace" )
   	handleAceArj(origin,type);
   else if( type == "-rpm" )
   	handleRpm(origin);
+	else if( type == "-iso" )
+		handleIso(origin);
 	else{
     if (!quietMode) KMessageBox::error(krApp,"Unknown temp_vfs type.");
     error = true;
@@ -69,10 +64,16 @@ temp_vfs::temp_vfs( QString origin, QString type, QWidget* panel, bool writeable
 }
 
 temp_vfs::~temp_vfs(){
-  // delete the temp dir
-  KShellProcess proc;
-  proc << "rm -rf" << tmpDir;
-  proc.start(KProcess::DontCare);
+	if( vfs_type == "-iso" ){
+		// unmount the ISO image
+    KShellProcess umount;
+		umount << "umount -f" << tmpDir;
+    umount.start(KProcess::Block);
+	}
+ 	// delete the temp dir
+ 	KShellProcess proc;
+ 	proc << "rm -rf" << tmpDir;
+ 	proc.start(KProcess::DontCare);
 }
 
 // return the working dir
@@ -124,3 +125,10 @@ void temp_vfs::handleRpm(QString origin){
 	rpm << "rpm -lpq"<<"\""+origin+"\""+" > "+tmpDir+"/filelist.txt";
 	rpm.start(KProcess::Block);
 }
+
+void temp_vfs::handleIso(QString origin){
+	// mount the ISO image
+	KShellProcess mount;
+	mount << "mount" << "-o loop" << origin << tmpDir;
+	mount.start(KProcess::Block);
+}
