@@ -61,7 +61,7 @@
 
 ////////////////////////[Look&Feel]
 // Filelist Font ///////
-#define _FilelistFont   new QFont("helvetica",12)
+#define _FilelistFont   new QFont("helvetica",11)
 // Warn On Exit ////////
 #define _WarnOnExit     false
 // Minimize To Tray ////
@@ -95,7 +95,7 @@
 
 /////////////////////// [Advanced]
 // Permission Check ///
-#define _PermCheck     true
+//#define _PermCheck     true
 // AutoMount //////////
 #define _AutoMount     false
 // Confirm Unempty Dir //     (for delete)
