@@ -37,22 +37,23 @@
 #include <klocale.h>
 #include <kprocess.h>
 #include <kmessagebox.h>
+#include <klineeditdlg.h>
 #include <kkeydialog.h>
 #include <kdirnotify_stub.h>
 #include <kio/netaccess.h>
 #include <kedittoolbar.h>
 #include <kdeversion.h>
+#include <kcmdlineargs.h>
+#include <KViewer/krviewer.h>
 // Krusader includes
 #include "krslots.h"
 #include "krusader.h"
 #include "krusaderview.h"
-#include "Panel/kvfspanel.h"
+#include "Panel/listpanel.h"
 #include "Dialogs/krdialogs.h"
 #include "Dialogs/krspwidgets.h"
-#include "BookMan/bookman.h"
 #include "GUI/krusaderstatus.h"
 #include "RemoteMan/remoteman.h"
-#include "Panel/kvfspanel.h"
 #include "Panel/panelfunc.h"
 #include "Konfigurator/konfigurator.h"
 #include "MountMan/kmountman.h"
@@ -64,33 +65,37 @@
 #include "Search/krsearchmod.h"
 #include "Search/krsearchdialog.h"
 #include "VFS/vfs.h"
+#include "panelmanager.h"
 
 #define ACTIVE_PANEL        (krApp->mainView->activePanel)
 #define ACTIVE_FUNC         (krApp->mainView->activePanel->func)
 #define MAIN_VIEW           (krApp->mainView)
-#define REFRESH_BOTH_PANELS { KVFSPanel *p=ACTIVE_PANEL;MAIN_VIEW->left->refresh(); \
-	                            MAIN_VIEW->right->refresh(); p->slotFocusOnMe(); }
+#define REFRESH_BOTH_PANELS { ListPanel *p=ACTIVE_PANEL;        \
+                              MAIN_VIEW->left->func->refresh(); \
+	                            MAIN_VIEW->right->func->refresh();\
+                              p->slotFocusOnMe(); }
+#define ACTIVE_PANEL_MANAGER  (ACTIVE_PANEL == krApp->mainView->left ? krApp->mainView->leftMng : \
+                                krApp->mainView->rightMng)
 
 
 void KRslots::selectCompareMask() {
   int left=0,right=0;
   KRSpWidgets::selectCompareColorMask(&left, &right);
-  kdWarning() << left << endl;
   if (left>0 && right>0) { // safeguard
-  kdWarning() << left << endl;
     MAIN_VIEW->left->colorMask = left;
     MAIN_VIEW->right->colorMask = right;
-    if (krCompareDirs->isChecked() && MAIN_VIEW->left->type == "list" &&
-        MAIN_VIEW->right->type == "list") {
-      ((ListPanel*)MAIN_VIEW->left)->fileList->clear();
+    if (krCompareDirs->isChecked() ) {
+      ((ListPanel*)MAIN_VIEW->left)->view->clear();
       ((ListPanel*)MAIN_VIEW->left)->slotUpdate();
-      ((ListPanel*)MAIN_VIEW->right)->fileList->clear();
+      ((ListPanel*)MAIN_VIEW->right)->view->clear();
       ((ListPanel*)MAIN_VIEW->right)->slotUpdate();
     }
   }
 }
 
 void KRslots::compareDirectories() {
+  KMessageBox::sorry(0, i18n("Compare mode is temporarily disabled. sorry"));
+
   if (!krCompareDirs->isChecked()) {
     ACTIVE_PANEL->compareMode = false;
     ACTIVE_PANEL->otherPanel->compareMode = false;
@@ -134,9 +139,6 @@ void KRslots::compareContent() {
     return;
   }
 
-  if (ACTIVE_PANEL->type != "list" || ACTIVE_PANEL->otherPanel->type != "list")
-    return; // safety
-
   QStringList lst1, lst2;
   QString name1, name2;
 
@@ -156,38 +158,42 @@ void KRslots::compareContent() {
 
   // else implied: all ok, let's call kdiff
 	// but if one of the files isn't local, download them first
-	KURL url1 = ACTIVE_PANEL->files->vfs_getFile(name1);
-	KURL url2 = ACTIVE_PANEL->otherPanel->files->vfs_getFile(name2);
-	
+	KURL url1 = ACTIVE_FUNC->files()->vfs_getFile(name1);
+	KURL url2 = ACTIVE_PANEL->otherPanel->func->files()->vfs_getFile(name2);
+
 	QString tmp1 = QString::null, tmp2 = QString::null;
   if (!url1.isLocalFile()) {
  		if( !KIO::NetAccess::download( url1, tmp1 ) ){
       KMessageBox::sorry(krApp,i18n("Krusader is unable to download: ")+name1);
       return;
     }
-	} else tmp1 = url1.url();
+	} else tmp1 = url1.path();
   if (!url2.isLocalFile()) {
  		if( !KIO::NetAccess::download( url2, tmp2 ) ){
       KMessageBox::sorry(krApp,i18n("Krusader is unable to download: ")+name1);
       return;
     }
-	} else tmp2 = url2.url();
-  kdWarning() << tmp1.mid(tmp1.find('/')) << "," << tmp2.mid(tmp2.find('/')) <<endl;
+	} else tmp2 = url2.path();
 
-  KShellProcess p;
-  p << diffProg << tmp1.mid(tmp1.find('/')) << tmp2.mid(tmp2.find('/'));
+  KProcess p;
+  p << diffProg << tmp1 << tmp2;
 	if (!p.start(KProcess::DontCare))
     KMessageBox::error(0,i18n("Error executing ")+diffProg+" !");
   else
     p.detach();
-  sleep(2);	
+  sleep(2);
 
-	if( tmp1 != url1.url() ) KIO::NetAccess::removeTempFile( tmp1 );
-	if( tmp2 != url2.url() ) KIO::NetAccess::removeTempFile( tmp2 );
+	if( tmp1 != url1.path() ) KIO::NetAccess::removeTempFile( tmp1 );
+	if( tmp2 != url2.path() ) KIO::NetAccess::removeTempFile( tmp2 );
 }
 
 void KRslots::rightclickMenu() {
-  ACTIVE_PANEL->popRightClickMenu();
+  ACTIVE_PANEL->popRightClickMenu(
+   ACTIVE_PANEL->mapToGlobal(
+   dynamic_cast<KListView*>(ACTIVE_PANEL->view)->itemRect(dynamic_cast<QListViewItem*>
+   (ACTIVE_PANEL->view->getCurrentKrViewItem())).topLeft()
+   )
+  );
 }
 
 void KRslots::addBookmark(){
@@ -195,7 +201,6 @@ void KRslots::addBookmark(){
   if (path.contains('\\')>0)
     KMessageBox::information(0, i18n("In order to save the time needed to enter an archive, Krusader will not allow bookmarks which point into an archive, as it is usually a mistake to do so!"),
                              QString::null, "BookmarkArchives");
-  else krBookMan->addBookmark(path);
 }
 
 // GUI toggle slots
@@ -231,20 +236,40 @@ void KRslots::showAboutApplication() {
   q->exec();
 }
 
+void KRslots::insertFileName(bool full_path)
+{
+  QString filename = ACTIVE_PANEL->view->getCurrentItem();
+  if( filename == QString::null )
+    return;
+  
+  if( full_path )
+  {
+    QString path=ACTIVE_FUNC->files()->vfs_getOrigin();
+    if( !path.endsWith( "/" ))
+      path+="/";
+    filename = path+filename;
+  }
+
+  QString current = MAIN_VIEW->cmdLine->text();
+  if( current.length() != 0 && !current.endsWith( " " ) )
+    current += " ";
+  MAIN_VIEW->cmdLine->setText( current + filename );
+}
+
 // directory list functions
-void KRslots::allFilter()			  {	ACTIVE_PANEL->setFilter(KVFSPanel::ALL);	 }
-void KRslots::execFilter()			{	ACTIVE_PANEL->setFilter(KVFSPanel::EXEC);	 }
-void KRslots::customFilter()		{	ACTIVE_PANEL->setFilter(KVFSPanel::CUSTOM);}
+void KRslots::allFilter()			  {	ACTIVE_PANEL->setFilter(KrView::All);	 }
+void KRslots::execFilter()			{	ACTIVE_PANEL->setFilter(KrView::All);	 }
+void KRslots::customFilter()		{	ACTIVE_PANEL->setFilter(KrView::Custom);}
 void KRslots::markAll()         { ACTIVE_PANEL->select(true,true);           }
 void KRslots::unmarkAll()       { ACTIVE_PANEL->select(false,true);          }
 void KRslots::markGroup()       { ACTIVE_PANEL->select(true,false);          }
 void KRslots::unmarkGroup()     { ACTIVE_PANEL->select(false,false);         }
 void KRslots::invert()          { ACTIVE_PANEL->invertSelection();           }
-void KRslots::root()            { ACTIVE_PANEL->openUrl("/");                }
-void KRslots::refresh()         { ACTIVE_PANEL->refresh();                   }
-void KRslots::refresh(QString p){ ACTIVE_PANEL->openUrl(p);                  }
-void KRslots::home()            { ACTIVE_PANEL->openUrl(QDir::homeDirPath());}
 
+void KRslots::root()            { ACTIVE_FUNC->openUrl("/");                 }
+void KRslots::refresh(QString p){ ACTIVE_FUNC->openUrl(p);                   }
+void KRslots::home()            { ACTIVE_FUNC->openUrl(QDir::homeDirPath()); }
+void KRslots::refresh()         { ACTIVE_FUNC->refresh();                    }
 void KRslots::properties()      { ACTIVE_FUNC->properties();                 }
 void KRslots::dirUp()           { ACTIVE_FUNC->dirUp();                      }
 void KRslots::back()            { ACTIVE_FUNC->goBack();                     }
@@ -256,21 +281,9 @@ void KRslots::FTPDisconnect()   { ACTIVE_FUNC->FTPDisconnect();              }
 void KRslots::newFTPconnection(){ newFTPconnection(QString::null); 					 }
 void KRslots::newFTPconnection(QString host)
                					        { ACTIVE_FUNC->newFTPconnection(host);       }
-void KRslots::setTreeView()     { MAIN_VIEW->setTreeView();                  }
-void KRslots::setListView()     { MAIN_VIEW->setListView();                  }
-void KRslots::setQuickView()		{ MAIN_VIEW->setQuickView();						     }
-
 // run external modules / programs
 void KRslots::runKonfigurator(bool firstTime) { delete new Konfigurator(firstTime); }
 
-void KRslots::toggleSortByExt() {
-  krConfig->setGroup("Look&Feel");
-	bool ext = !krConfig->readBoolEntry("Sort By Extention",_SortByExt);
-	krApp->actToggleSortByExt->setChecked(ext);
-  krConfig->writeEntry("Sort By Extention",ext);
-  REFRESH_BOTH_PANELS;
-}
-
 void KRslots::toggleHidden(){
   krConfig->setGroup("Look&Feel");
 	bool show = !krConfig->readBoolEntry("Show Hidden",_ShowHidden);
@@ -279,12 +292,29 @@ void KRslots::toggleHidden(){
 	REFRESH_BOTH_PANELS;
 }
 
+void KRslots::toggleSwapPanels(){
+  PanelManager *currentFirst = panel_swap ? MAIN_VIEW->rightMng : MAIN_VIEW->leftMng;
+	krApp->actToggleSwapPanels->setChecked( panel_swap = !panel_swap );
+  MAIN_VIEW->horiz_splitter->moveToLast( currentFirst );
+  MAIN_VIEW->left->updateGeometry();
+  MAIN_VIEW->right->updateGeometry();
+}
+
 void KRslots::search() {
   new KrSearchDialog();
 }
 
 void KRslots::runRemoteMan() {
-	QString host=remoteMan::getHost();
+  // display outage information
+  KMessageBox::information(krApp, i18n( "Important: RemoteMan has been replaced by our new bookmark manager."
+                                        "The new manager handles local files and remote url the same way."
+                                        "RemoteMan is being left around to allow an easier transition and"
+                                        "give you a chance to move your bookmarks. IT WILL BE REMOVED SOON!"
+                                        "\n"
+                                        "Try the new bookmark-manager: open a new remote connection. once"
+                                        "done, press the bookmark button, select 'Add bookmark' and that's it!"));
+
+  QString host=remoteMan::getHost();
 	if (host==QString::null) return;
 	// otherwise, attempt a connection
 	newFTPconnection(host);
@@ -327,12 +357,10 @@ void KRslots::multiRename(){
   	return;
 	}
 	QString pathToRename = lst[i+1];
-
-	if ( ACTIVE_PANEL->type != "list" ) return; // safety
 	
   QStringList names;
   ((ListPanel*)ACTIVE_PANEL)->getSelectedNames(&names);
-	KURL::List* urls = ((ListPanel*)ACTIVE_PANEL)->files->vfs_getFiles(&names);
+	KURL::List* urls = ACTIVE_FUNC->files()->vfs_getFiles(&names);
 
 	if( urls->isEmpty() ){
 		delete urls;
@@ -344,13 +372,21 @@ void KRslots::multiRename(){
 
 	for( KURL::List::iterator u=urls->begin(); u != urls->end(); ++u){
     if( QFileInfo((*u).path()).isDir() ) proc << "-r";
-		proc << (*u).path();	
+		proc << "\"" + (*u).path() + "\""; // patch thanks to Tobias Vogele
 	}
 
 	proc.start(KProcess::DontCare);
 	delete urls;
 }
 
+void KRslots::rootKrusader(){
+  KShellProcess proc;
+  proc << "kdesu" << QString("'") + KCmdLineArgs::appName() +
+       " --left=" +MAIN_VIEW->left->func->files()->vfs_getOrigin() +
+       " --right="+MAIN_VIEW->right->func->files()->vfs_getOrigin() + "'";
+
+  proc.start(KProcess::DontCare);
+}
 
 // settings slots
 void KRslots::configToolbar(){
@@ -393,4 +429,69 @@ void KRslots::deleteFiles()    { ACTIVE_FUNC->deleteFiles();}
 // F9
 void KRslots::rename()         { ACTIVE_FUNC->rename();     }
 
+// Shift F3
+void KRslots::viewDlg(){
+  // ask the user for a url to view
+  KChooseDir *chooser = new KChooseDir( 0,i18n("Enter a URL to view:"), QString::null);
+  QString dest = chooser->dest;
+  if ( dest == QString::null ) return ; // the usr canceled
+  else
+  {
+    /* KURL::fromPathOrURL requires fullpath, so we check whether it is relative  */
+    if ( !dest.contains( ":/" ) && !dest.startsWith( "/" ) )
+      dest = ACTIVE_FUNC->files()->vfs_getOrigin() + "/" + dest; /* it's full path now */
+    
+    KrViewer::view( KURL::fromPathOrURL(dest) ); // view the file
+  }
+  // nothing more to it!
+}
+
+// Shift F4
+void KRslots::editDlg(){
+  // ask the user for the filename to edit
+  KChooseDir *chooser = new KChooseDir( 0,i18n("Enter the filename to edit:"), QString::null);
+  QString dest = chooser->dest;
+  if ( dest == QString::null ) return ; // the usr canceled
+  else
+  {
+    /* KURL::fromPathOrURL requires fullpath, so we check whether it is relative  */
+    if ( !dest.contains( ":/" ) && !dest.startsWith( "/" ) )
+      dest = ACTIVE_FUNC->files()->vfs_getOrigin() + "/" + dest; /* it's full path now */
+    
+    krConfig->setGroup( "General" );
+    QString edit = krConfig->readEntry( "Editor", _Editor );
+
+    if ( edit == "internal editor" )
+      KrViewer::edit( KURL::fromPathOrURL( dest ), true );
+    else {
+      KProcess proc;
+      proc << edit << dest;
+      if ( !proc.start( KProcess::DontCare ) )
+        KMessageBox::sorry( krApp, i18n( "Can't open " ) + "\"" + edit + "\"" );
+    }
+  }
+  // nothing more to it!
+}
+
+void KRslots::duplicateTab() {
+  ACTIVE_PANEL_MANAGER->slotNewTab(ACTIVE_PANEL->virtualPath);
+}
+
+void KRslots::newTab() {
+  ACTIVE_PANEL_MANAGER->slotNewTab();
+}
+
+void KRslots::newTab(QListViewItem *item) {
+  if (!item) return;
+  KrViewItem *it = dynamic_cast<KrViewItem*>(item);
+  if (it->isDir()) {
+    ACTIVE_PANEL_MANAGER->slotNewTab(ACTIVE_PANEL->virtualPath + "/" + it->name());
+    kdWarning() << ACTIVE_PANEL->virtualPath << it->name()<<endl;
+  }
+}
+
+void KRslots::closeTab() {
+  ACTIVE_PANEL_MANAGER->slotCloseTab();
+}
+
 #include "krslots.moc"
