@@ -32,7 +32,8 @@
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 #include <klocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
+#include <unistd.h>
 
 // Krusader includes
 #include "krusader.h"
@@ -43,34 +44,53 @@ static const char *description =
 
 static KCmdLineOptions options[] =
 {
+  { "left <path>", I18N_NOOP("Start left panel at <path>"), 0},
+  { "right <path>", I18N_NOOP("Start right panel at <path>"), 0},
   { 0, 0, 0 }
   // INSERT YOUR COMMANDLINE OPTIONS HERE
 };
 
 int main(int argc, char *argv[]) {
   // ABOUT data information
-  KAboutData aboutData( "krusader", I18N_NOOP("Krusader"),
+  KAboutData aboutData( "krusader", ( geteuid() ? I18N_NOOP("Krusader") :
+                        I18N_NOOP("Krusader - ROOT PRIVILEGES")),
     VERSION, description, KAboutData::License_GPL,
-    "(c) 2000-2002, Shie Erlich & Rafi Yanai",
+    "(c) 2000-2003, Shie Erlich and Rafi Yanai",
     0,
     "http://krusader.sourceforge.net",
     "krusader@users.sourceforge.net");
-  aboutData.addAuthor("Rafi Yanai",0, "yanai@users.sourceforge.net");
-  aboutData.addAuthor("Shie Erlich",0, "manson@users.sourceforge.net");
-  aboutData.addCredit("Dirk Eschler", "Webmaster", "homebass@gmx.net", 0);
+  aboutData.addAuthor("Rafi Yanai","Author", "yanai@users.sourceforge.net");
+  aboutData.addAuthor("Shie Erlich","Author", "manson@users.sourceforge.net");
+  aboutData.addAuthor("Dirk Eschler", "Webmaster and i18n coordinator", "homebass@gmx.net", 0);
+  aboutData.addAuthor("Jan Halasa", "Developer", "xhalasa@fi.muni.cz", 0);
+  aboutData.addAuthor("Karai Csaba", "Developer", "ckarai@users.sourceforge.net", 0);
+  aboutData.addCredit("Heiner Eichmann","The 6th Beatle: FreeBSD port, patches and general help", "h.eichmann@gmx.de", 0);
+  aboutData.addCredit("Mikolaj Machowski", "Usability and QA", "<mikmach@wp.pl>", 0);
   aboutData.addCredit("Cristi Dumitrescu","QA, bug-hunting, patches and general help","cristid@chip.ro",0);
   aboutData.addCredit("Aurelien Gateau","patch for KViewer","aurelien.gateau@free.fr",0);
+  aboutData.addCredit("Rafael Munoz","Spanish translation","muror@hotpop.com",0);
+  aboutData.addCredit("Zdenko Podobna","Slovak translation","zdpo@mailbox.sk",0);
+  aboutData.addCredit("Frank Schoolmeesters","Dutch translation","frank_schoolmeesters@yahoo.com",0);
+  aboutData.addCredit("Giuseppe Bordoni", "Italian translation", "geppo@geppozone.com", 0);
+  aboutData.addCredit("UTUMI Hirosi", "Japanese translation", "utuhiro@mx12.freecom.ne.jp", 0);
   aboutData.addCredit("Anders Bruun Olsen", "Danish translation", "anders@bruun-olsen.net", 0);
   aboutData.addCredit("Erik Johanssen","Swedish translation","erre@telia.com",0);
+  aboutData.addCredit("Anders Linden","Updated Swedish translation","connyosis@gmx.net",0);
   aboutData.addCredit("Mitek","Czech translation","mitek@email.cz",0);
-  aboutData.addCredit("Crissi","German translation","crissi99@gmx.de",0);
+  aboutData.addCredit("Christoph Thielecke","German translation","crissi99@gmx.de",0);
   aboutData.addCredit("René-Pierre Lehmann","French translation","ripi@lepi.org",0);
+  aboutData.addCredit("Rafa Munoz","Spanish translation","muror@iespana.es",0);
+  aboutData.addCredit("Lukasz Janyst","Polish translation","ljan@wp.pl",0);
+  aboutData.addCredit("Kukk Zoltan","Hungarian translation","kukkzoli@freemail.hu",0);
+  aboutData.addCredit("Dmitry Chernyak","Russian translation","chernyak@mail.ru",0);
   aboutData.addCredit("Milan Brabec","the first patch ever !","mbrabec@volny.cz",0);
 
   // Command line arguments ...
   KCmdLineArgs::init( argc, argv, &aboutData );
   KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
 
+  // check for command line arguments
+
   // create the application
   KApplication app;
   Krusader *krusader = new Krusader();
